@@ -5,7 +5,7 @@ import sys, os, re, cPickle
 import numpy
 
 __author__ = ""
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Rob Knight", "Peter Maxwell",
                     "Jeremy Widmann", "Catherine Lozupone", "Matthew Wakefield",
                     "Edward Lang", "Greg Caporaso", "Mike Robeson",
@@ -14,15 +14,15 @@ __credits__ = ["Gavin Huttley", "Rob Knight", "Peter Maxwell",
                     "Hua Ying", "Jason Carnes", "Raymond Sammut",
                     "Helen Lindsay", "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
 
 #SUPPORT2425
-if sys.version_info < (2, 5):
+if sys.version_info < (2, 6):
     py_version = ".".join([str(n) for n in sys.version_info])
-    raise RuntimeError("Python-2.5 or 2.6 is required, Python-%s used." % py_version)
+    raise RuntimeError("Python-2.6 or greater is required, Python-%s used." % py_version)
 
 numpy_version = re.split("[^\d]", numpy.__version__)
 numpy_version_info = tuple([int(i) for i in numpy_version if i.isdigit()])
@@ -127,7 +127,7 @@ def LoadStructure(filename, format=None, parser_kw={}):
 def LoadTable(filename=None, sep=',', reader=None, header=None, rows=None,
             row_order=None, digits=4, space=4, title='', missing_data='',
             max_width = 1e100, row_ids=False, legend='', column_templates=None,
-            dtype=None, static_column_types=False, **kwargs):
+            dtype=None, static_column_types=False, limit=None, **kwargs):
     """
     Arguments:
     - filename: path to file containing a pickled table
@@ -154,6 +154,8 @@ def LoadTable(filename=None, sep=',', reader=None, header=None, rows=None,
     - column_templates: dict of column headings: string format templates
       or a function that will handle the formatting.
     - dtype: optional numpy array typecode.
+    - limit: exits after this many lines. Only applied for non pickled data
+      file types.
     """
     # 
     if filename is not None and not (reader or static_column_types):
@@ -165,12 +167,12 @@ def LoadTable(filename=None, sep=',', reader=None, header=None, rows=None,
 
         sep = sep or kwargs.pop('delimiter', None)
         header, rows, loaded_title, legend = load_delimited(filename,
-                                        delimiter = sep, **kwargs)
+                                    delimiter = sep, limit=limit, **kwargs)
         title = title or loaded_title
     elif filename and (reader or static_column_types):
         f = file(filename, "r")
         if not reader:
-            reader = autogen_reader(f, sep,
+            reader = autogen_reader(f, sep, limit=limit,
                         with_title=kwargs.get('with_title', False))
         
         rows = [row for row in reader(f)]
