@@ -3,29 +3,206 @@
 """
 
 __author__ = "Kyle Bittinger"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Kyle Bittinger","Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Kyle Bittinger"
 __email__ = "kylebittinger@gmail.com"
 __status__ = "Prototype"
 
 
+import os.path
+import re
 from os import remove, environ, getenv, path
-from os.path import exists
 from optparse import OptionParser
 from shutil import rmtree
-from tempfile import mkdtemp
+import tempfile
 from cogent.app.parameters import Parameter, ValuedParameter, Parameters
 from cogent.parse.fasta import MinimalFastaParser
 from cogent.app.util import CommandLineApplication, CommandLineAppResult, \
     FilePath, ResultPath, guess_input_handler, system,\
     ApplicationNotFoundError, ApplicationError
+from cogent.util.misc import app_path
 
 class RdpClassifier(CommandLineApplication):
     """RDP Classifier application controller
 
+    The RDP Classifier program is distributed as a java archive (.jar)
+    file.  If the file 'rdp_classifier-2.2.jar' is not found in the
+    current directory, the app controller uses the JAR file specified
+    by the environment variable RDP_JAR_PATH.  If this variable is not
+    set, and 'rdp_classifier-2.2.jar' is not found in the current
+    directory, the application controller raises an
+    ApplicationNotFoundError.
+
+    The RDP Classifier often requires memory in excess of Java's
+    default 64M. To correct this situation, the authors recommend
+    increasing the maximum heap size for the java virtual machine.  An
+    option '-Xmx' (default 1000M) is provided for this purpose.
+    Details on this option may be found at
+    http://java.sun.com/j2se/1.5.0/docs/tooldocs/solaris/java.html
+
+    The classifier may optionally use a custom training set.  The full
+    path to the training set may be provided in the option
+    '-training-data'.
+    """
+    _input_handler = '_input_as_lines'
+    _command = "rdp_classifier-2.2.jar"
+    _options = {
+        # output file name for classification assignment
+        '-o': ValuedParameter('-', Name='o', Delimiter=' ', IsPath=True),
+        # a property file contains the mapping of the training
+        # files. Note: the training files and the property file should
+        # be in the same directory. The default property file is set
+        # to data/classifier/rRNAClassifier.properties.
+        '-t': ValuedParameter('-', Name='t', Delimiter=' ', IsPath=True),
+        # all tab delimited output format: [allrank|fixrank|db].
+        # Default is allrank.
+        #
+        #   allrank: outputs the results for all ranks applied for
+        #   each sequence: seqname, orientation, taxon name, rank,
+        #   conf, ...
+        #
+        #   fixrank: only outputs the results for fixed ranks in
+        #   order: no rank, domain, phylum, class, order, family,
+        #   genus
+        #
+        #   db: outputs the seqname, trainset_no, tax_id, conf. This
+        #   is good for storing in a database
+        '-f': ValuedParameter('-', Name='f', Delimiter=' '),
+        }
+
+    # The following are available in the attributes JvmParameters,
+    # JarParameters, and PositionalParameters
+
+    _jvm_synonyms = {}
+    _jvm_parameters = {
+        # Maximum heap size for JVM.
+        '-Xmx': ValuedParameter('-', Name='Xmx', Delimiter='', Value='1000m'),
+        }
+
+    _parameters = {}
+    _parameters.update(_options)
+    _parameters.update(_jvm_parameters)
+
+    def getHelp(self):
+        """Returns documentation string"""
+        # Summary paragraph copied from rdp_classifier-2.0, which is
+        # licensed under the GPL 2.0 and Copyright 2008 Michigan State
+        # University Board of Trustees
+        help_str = """\
+        usage: ClassifierCmd [-f <arg>] [-o <arg>] [-q <arg>] [-t <arg>]
+
+        -f,--format <arg> all tab delimited output format:
+        [allrank|fixrank|db]. Default is allrank.
+
+            allrank: outputs the results for all ranks applied for each
+            sequence: seqname, orientation, taxon name, rank, conf, ...
+
+            fixrank: only outputs the results for fixed ranks in order:
+            no rank, domain, phylum, class, order, family, genus
+
+            db: outputs the seqname, trainset_no, tax_id, conf. This is
+            good for storing in a database
+
+        -o,--outputFile <arg> output file name for classification
+        assignment
+
+        -q,--queryFile <arg> query file contains sequences in one of
+        the following formats: Fasta, Genbank and EMBL
+
+        -t,--train_propfile <arg> a property file contains the mapping
+        of the training files.
+        
+        Note: the training files and the property file should be in
+        the same directory. The default property file is set to
+        data/classifier/rRNAClassifier.properties."""
+        return help_str
+
+    def _accept_exit_status(self, status):
+        """Returns false if an error occurred in execution
+        """
+        return (status == 0)
+
+    def _error_on_missing_application(self,params):
+        """Raise an ApplicationNotFoundError if the app is not accessible
+
+        In this case, checks for the java runtime and the RDP jar file.
+        """
+        if not (os.path.exists('java') or app_path('java')):
+            raise ApplicationNotFoundError(
+                "Cannot find java runtime. Is it installed? Is it in your "
+                "path?")
+        jar_fp = self._get_jar_fp()
+        if jar_fp is None:
+            raise ApplicationNotFoundError(
+                "JAR file not found in current directory and the RDP_JAR_PATH "
+                "environment variable is not set.  Please set RDP_JAR_PATH to "
+                "the full pathname of the JAR file.")
+        if not os.path.exists(jar_fp):
+            raise ApplicationNotFoundError(
+                "JAR file %s does not exist." % jar_fp)
+
+    def _get_jar_fp(self):
+        """Returns the full path to the JAR file.
+
+        If the JAR file cannot be found in the current directory and
+        the environment variable RDP_JAR_PATH is not set, returns
+        None.
+        """
+        # handles case where the jar file is in the current working directory
+        if os.path.exists(self._command):
+            return self._command
+        # handles the case where the user has specified the location via
+        # an environment variable
+        elif 'RDP_JAR_PATH' in environ:
+            return getenv('RDP_JAR_PATH')
+        else:
+            return None
+
+    # Overridden to pull out JVM-specific command-line arguments.
+    def _get_base_command(self):
+        """Returns the base command plus command-line options.
+
+        Does not include input file, output file, and training set.
+        """
+        cd_command = ''.join(['cd ', str(self.WorkingDir), ';'])
+        jvm_command = "java"
+        jvm_arguments = self._commandline_join(
+            [self.Parameters[k] for k in self._jvm_parameters])
+        jar_arguments = '-jar "%s"' % self._get_jar_fp()
+        rdp_arguments = self._commandline_join(
+            [self.Parameters[k] for k in self._options])
+
+        command_parts = [
+            cd_command, jvm_command, jvm_arguments, jar_arguments,
+            rdp_arguments, '-q']
+        return self._commandline_join(command_parts).strip()
+    
+    BaseCommand = property(_get_base_command)
+
+    def _commandline_join(self, tokens):
+        """Formats a list of tokens as a shell command
+ 
+        This seems to be a repeated pattern; may be useful in
+        superclass.
+        """
+        commands = filter(None, map(str, tokens))
+        return self._command_delimiter.join(commands).strip()
+
+    def _get_result_paths(self,data):
+        """ Return a dict of ResultPath objects representing all possible output
+        """
+        assignment_fp = str(self.Parameters['-o'].Value).strip('"')
+        if not os.path.isabs(assignment_fp):
+            assignment_fp = os.path.relpath(assignment_fp, self.WorkingDir)
+        return {'Assignments': ResultPath(assignment_fp, IsWritten=True)}
+
+
+class RdpClassifier20(RdpClassifier):
+    """RDP Classifier version 2.0 application controller
+
     The RDP Classifier program is distributed as a java archive (.jar)
     file.  If the file 'rdp_classifier-2.0.jar' is not found in the
     current directory, the app controller looks in the directory
@@ -113,10 +290,11 @@ class RdpClassifier(CommandLineApplication):
         input_handler = self.InputHandler
         suppress_stdout = self.SuppressStdout
         suppress_stderr = self.SuppressStderr
+        assignment_fp = FilePath(self.getTmpFilename(self.TmpDir))
         if suppress_stdout:
             outfile = FilePath('/dev/null')
         else:
-            outfile = self.getTmpFilename(self.TmpDir)
+            outfile = FilePath(self.getTmpFilename(self.TmpDir))
         if suppress_stderr:
             errfile = FilePath('/dev/null')
         else:
@@ -131,8 +309,8 @@ class RdpClassifier(CommandLineApplication):
         # Build up the command, consisting of a BaseCommand followed by
         # input and output (file) specifications
         command = self._commandline_join(
-            [self.BaseCommand, input_arg, outfile, training_data, 
-             '2>', errfile,]
+            [self.BaseCommand, input_arg, assignment_fp, training_data, 
+             '>', outfile, '2>', errfile,]
             )
 
         if self.HaltExec: 
@@ -157,9 +335,11 @@ class RdpClassifier(CommandLineApplication):
         err = None        
         if not suppress_stderr:
             err = open(errfile,"r")
-       
+
+        result_paths = self._get_result_paths(data)
+        result_paths['Assignments'] = ResultPath(assignment_fp)
         result = CommandLineAppResult(
-            out, err, exit_status, result_paths=self._get_result_paths(data))
+            out, err, exit_status, result_paths=result_paths)
 
         # Clean up the input file if one was created
         if remove_tmp:
@@ -269,183 +449,71 @@ class RdpClassifier(CommandLineApplication):
 
 class RdpTrainer(RdpClassifier):
     _input_handler = '_input_as_lines'
-    TrainingClass = 'edu/msu/cme/rdp/classifier/train/ClassifierTraineeMaker'
+    TrainingClass = 'edu.msu.cme.rdp.classifier.train.ClassifierTraineeMaker'
     PropertiesFile = 'RdpClassifier.properties'
 
-    def __call__(self, training_seqs_file, taxonomy_file, model_output_dir,
-        remove_tmp=True):
-        return self._train_with_rdp_files(
-            training_seqs_file, taxonomy_file, model_output_dir, remove_tmp)
+    _rdp_parameters = {
+        'taxonomy_file': ValuedParameter(None, None, IsPath=True),
+        'model_output_dir': ValuedParameter(None, None, IsPath=True),
+        'training_set_id': ValuedParameter(None, None, Value='1'),
+        'taxonomy_version': ValuedParameter(None, None, Value='version1'),
+        'modification_info': ValuedParameter(None, None, Value='cogent'),
+        }
+    _jvm_parameters = {
+        # Maximum heap size for JVM.
+        '-Xmx': ValuedParameter('-', Name='Xmx', Delimiter='', Value='1000m'),
+        }
+    _parameters = {}
+    _parameters.update(_rdp_parameters)
+    _parameters.update(_jvm_parameters)
 
-    def _train_with_mapping_file(self, training_seqs_file, lineage_file,
-        model_output_dir, remove_tmp=True):
-        """Creates a set of training data for the RDP Classifier
+    def _get_base_command(self):
+        """Returns the base command plus command-line options.
 
-            training_seqs_file: The set of training sequences, in
-                fasta format.
-
-            lineage_file: A File-like object that specifies a lineage
-                for each sequence. Each line must contain a Sequence
-                ID, followed by a tab, then followed by the assigned
-                lineage.  The taxa comprising the lineage must be
-                separated with a comma.
-
-            model_output_dir: Directory in which to store training data.
-
-            remove_tmp: if True, removes tmp files
-
-        To use the resulting model with the RdpClassifier, set
-        '-training_data' to the following path: model_output_dir +
-        RdpClassifier.PropertiesFile
+        Does not include input file, output file, and training set.
         """
+        cd_command = ''.join(['cd ', str(self.WorkingDir), ';'])
+        jvm_command = "java"
+        jvm_args = self._commandline_join(
+            [self.Parameters[k] for k in self._jvm_parameters])
+        cp_args = '-cp "%s" %s' % (self._get_jar_fp(), self.TrainingClass)
 
-    def _train_with_rdp_files(self, training_seqs_file, taxonomy_file, 
-        model_output_dir, remove_tmp=True):
-        """Creates a set of training data for the RDP Classifier
+        command_parts = [cd_command, jvm_command, jvm_args, cp_args]
+        return self._commandline_join(command_parts).strip()
+    
+    BaseCommand = property(_get_base_command)
 
-            training_seqs_file: A pre-classified set of training
-                sequences, in fasta-like format.  Each sequence must
-                be labelled with an identifier (no spaces) and an
-                assigned lineage (taxa separated by ';'). Example of
-                a valid label: ">seq1 ROOT;Ph1;Fam1;G1;"
-
-            taxonomy_file: A File-like object that specifies a
-                taxonomic heirarchy. Each line in the file must
-                contain a '*'-separated list of the following items:
-                Taxon ID, Taxon Name, Parent Taxon ID, Depth, and
-                Rank.  IDs should have an integer format.  Example of
-                a valid line: "1*Bacteria*0*0*domain"
-
-            model_output_dir: Directory in which to store training data.
-
-            remove_tmp: if True, removes tmp files
-
-        To use the resulting model with the RdpClassifier, set
-        '-training_data' to the following path: model_output_dir +
-        RdpClassifier.PropertiesFile
+    def _set_input_handler(self, method_name):
+        """Stores the selected input handler in a private attribute.
         """
-        # Three extra pieces of information are required to create
-        # training data.  Unless we want built-in support for
-        # versioned training sets, these may be set to sensible
-        # defaults.
-        training_set_id = '1'
-        taxonomy_version = 'version1'
-        modification_info = 'cogent'
+        self.__InputHandler = method_name
 
-        # The properties file specifies the names of the files in the
-        # training directory.  We use the example properties file
-        # directly from the rdp_classifier distribution, which lists
-        # the default set of files created by the application.  We
-        # must write this file explicitly after generating the
-        # training data.
-        properties = (
-            "# Sample ResourceBundle properties file\n"
-            "bergeyTree=bergeyTrainingTree.xml\n"
-            "probabilityList=genus_wordConditionalProbList.txt\n"
-            "probabilityIndex=wordConditionalProbIndexArr.txt\n"
-            "wordPrior=logWordPrior.txt\n"
-            "classifierVersion=Naive Bayesian rRNA Classifier Version 1.0, November 2003\n"
-            )
+    def _get_input_handler(self):
+        return '_input_handler_decorator'
 
-        input_handler = self.InputHandler
-        suppress_stdout = self.SuppressStdout
-        suppress_stderr = self.SuppressStderr
-        if suppress_stdout:
-            outfile = FilePath('/dev/null')
-        else:
-            outfile = self.getTmpFilename(self.TmpDir)
-        if suppress_stderr:
-            errfile = FilePath('/dev/null')
-        else:
-            errfile = FilePath(self.getTmpFilename(self.TmpDir))
+    InputHandler = property(_get_input_handler, _set_input_handler)
 
-        input_handler_function = getattr(self, input_handler)
-        taxonomy_filename = input_handler_function(taxonomy_file)
-        training_seqs_filename = input_handler_function(training_seqs_file)
+    @property
+    def ModelDir(self):
+        return os.path.abspath(self.Parameters['model_output_dir'])
 
-        # Build up the command, consisting of a BaseCommand followed
-        # by input and output (file) specifications 
-
-        # Example from rdp_classifier/sampledata/README: 
-        # java -Xmx400m -cp rdp_classifier-2.0.jar
-        # edu/msu/cme/rdp/classifier/train/ClassifierTraineeMaker
-        # mydata/mytaxon.txt mydata/mytrainseq.fasta 1 version1 test
-        # mydata
-        command = self._commandline_join(
-            [self.BaseCommand, taxonomy_filename, training_seqs_filename,
-             training_set_id, taxonomy_version, modification_info,
-             model_output_dir, '>', outfile, '2>', errfile]
-            )
-
-        if self.HaltExec: 
-            raise AssertionError, "Halted exec with command:\n" + command
-        # The return value of system is a 16-bit number containing the signal 
-        # number that killed the process, and then the exit status. 
-        # We only want to keep the exit status so do a right bitwise shift to 
-        # get rid of the signal number byte
-        exit_status = system(command) >> 8
-
-        # Determine if error should be raised due to exit status of 
-        # appliciation
-        if not self._accept_exit_status(exit_status):
-            raise ApplicationError, \
-             'Unacceptable application exit status: %s, command: %s'\
-                % (str(exit_status),command)
-
-        # must write properties file to output directory manually
-        properties_fp = path.join(model_output_dir, self.PropertiesFile)
-        properties_file = open(properties_fp, 'w')
-        properties_file.write(properties)
-        properties_file.close()
-
-        # open the stdout and stderr if not being suppressed
-        out = None
-        if not suppress_stdout:
-            out = open(outfile,"r")
-        err = None        
-        if not suppress_stderr:
-            err = open(errfile,"r")
-       
-        result = CommandLineAppResult(out, err, exit_status, 
-            result_paths=self._get_result_paths(model_output_dir))
-
-        # Clean up the input files
-        if remove_tmp:
-            remove(taxonomy_filename)
-            remove(training_seqs_filename)
-
-        return result
-
-    def _input_as_lines(self, data):
-        """ Write a seq of lines to a temp file and return the filename string.
-
-        This method has been overridden for RdpTrainer so that the
-        _input_filename attribute is not assigned.
-
-            data: a sequence to be written to a file, each element of the 
-                sequence will compose a line in the file
-           * Note: the result will be the filename as a FilePath object 
-            (which is a string subclass).
-
-           * Note: '\n' will be stripped off the end of each sequence element
-                before writing to a file in order to avoid multiple new lines
-                accidentally be written to a file
+    def _input_handler_decorator(self, data):
+        """Appends trailing parameters to selected input_handler's results.
         """
-        filename = FilePath(self.getTmpFilename(self.TmpDir))
-        data_file = open(filename, 'w')
-        # Parent method does not take advantage of laziness, due to
-        # temporary variable that contains entire file contents --
-        # better to write explicit loop over lines in the data source,
-        # storing only each line in turn.
-        for line in data:
-            line = str(line).strip('\n')
-            data_file.write(line)
-            data_file.write('\n')
-        data_file.close()
-        return filename
+        input_handler = getattr(self, self.__InputHandler)
+        input_parts = [
+            self.Parameters['taxonomy_file'],
+            input_handler(data),
+            self.Parameters['training_set_id'],
+            self.Parameters['taxonomy_version'],
+            self.Parameters['modification_info'],
+            self.ModelDir,
+            ]
+        return self._commandline_join(input_parts)
 
     def _get_result_paths(self, output_dir):
-        files = {
+        self._write_properties_file()
+        training_files = {
             'bergeyTree': 'bergeyTrainingTree.xml',
             'probabilityList': 'genus_wordConditionalProbList.txt',
             'probabilityIndex': 'wordConditionalProbIndexArr.txt',
@@ -453,39 +521,33 @@ class RdpTrainer(RdpClassifier):
             'properties': self.PropertiesFile,
         }
         result_paths = {}
-        for name, file in files.iteritems():
-            result_paths[name] = ResultPath(
-                Path=path.join(output_dir, file), IsWritten=True)
+        for key, filename in training_files.iteritems():
+            result_paths[key] = ResultPath(
+                Path=os.path.join(self.ModelDir, filename), IsWritten=True)
         return result_paths
     
-    # Overridden to pull out JVM-specific command-line arguments.
-    def _get_base_command(self):
-        """Returns the base command plus command-line options.
-
-        Does not include input file, output file, and training set.
-        """
-        # Necessary? Preserve for consistency.
-        if self._command is None:
-            raise ApplicationError, '_command has not been set.'
-
-        # Append a change directory to the beginning of the command to change 
-        # to self.WorkingDir before running the command
-        # WorkingDir should be in quotes -- filenames might contain spaces
-        cd_command = ''.join(['cd ',str(self.WorkingDir),';'])
-
-        jvm_command = "java"
-        jvm_arguments = self._commandline_join(self.JvmParameters.values())
-        jar_arguments = '-cp "%s"' % self._get_jar_fp()
-
-        result = self._commandline_join(
-            [cd_command, jvm_command, jvm_arguments, jar_arguments, self.TrainingClass]
+    def _write_properties_file(self):
+        # The properties file specifies the names of the files in the
+        # training directory.  We use the example properties file
+        # directly from the rdp_classifier distribution, which lists
+        # the default set of files created by the application.  We
+        # must write this file manually after generating the
+        # training data.
+        properties_fp = os.path.join(self.ModelDir, self.PropertiesFile)
+        properties_file = open(properties_fp, 'w')
+        properties_file.write(
+            "# Sample ResourceBundle properties file\n"
+            "bergeyTree=bergeyTrainingTree.xml\n"
+            "probabilityList=genus_wordConditionalProbList.txt\n"
+            "probabilityIndex=wordConditionalProbIndexArr.txt\n"
+            "wordPrior=logWordPrior.txt\n"
+            "classifierVersion=Naive Bayesian rRNA Classifier Version 1.0, "
+            "November 2003\n"
             )
-        return result
-
-    BaseCommand = property(_get_base_command)
+        properties_file.close()
 
 
-def parse_command_line_parameters():
+def parse_command_line_parameters(argv=None):
     """ Parses command line arguments """
     usage =\
      'usage: %prog [options] input_sequences_filepath'
@@ -502,97 +564,78 @@ def parse_command_line_parameters():
 
     parser.set_defaults(verbose=False,min_confidence=0.80)
 
-    opts,args = parser.parse_args()
-    num_args = 1
-    if len(args) != num_args:
+    opts, args = parser.parse_args(argv)
+    if len(args) != 1:
        parser.error('Exactly one argument is required.')
 
+    return opts, args
 
-    return opts,args
-    
-def assign_taxonomy(data, min_confidence=0.80, output_fp=None, training_data_fp=None):
-    """ Assign taxonomy to each sequence in data with the RDP classifier 
+
+def assign_taxonomy(
+    data, min_confidence=0.80, output_fp=None, training_data_fp=None,
+    fixrank=True):
+    """Assign taxonomy to each sequence in data with the RDP classifier
     
         data: open fasta file object or list of fasta lines
         confidence: minimum support threshold to assign taxonomy to a sequence
         output_fp: path to write output; if not provided, result will be 
          returned in a dict of {seq_id:(taxonomy_assignment,confidence)}
-    
     """
+    # Going to iterate through this twice in succession, best to force
+    # evaluation now
     data = list(data)
-    
-    # build a map of seq identifiers as the RDP classifier doesn't 
-    # preserve these perfectly
-    identifier_lookup = {}
+
+    # RDP classifier doesn't preserve identifiers with spaces
+    # Use lookup table
+    seq_id_lookup = {}
     for seq_id, seq in MinimalFastaParser(data):
-        identifier_lookup[seq_id.split()[0]] = seq_id
+        seq_id_lookup[seq_id.split()[0]] = seq_id
     
-    # build the classifier object
     app = RdpClassifier()
-    
+
+    temp_output_file = tempfile.NamedTemporaryFile(
+        prefix='RdpAssignments_', suffix='.txt')
+    app.Parameters['-o'].on(temp_output_file.name)
     if training_data_fp is not None:
-        app.Parameters['-training-data'].on(training_data_fp)
+        app.Parameters['-t'].on(training_data_fp)
+    if fixrank:
+        app.Parameters['-f'].on('fixrank')
 
-    # apply the rdp app controller
-    rdp_result = app('\n'.join(data))
-    # grab standard out
-    result_lines = rdp_result['StdOut']
+    app_result = app(data)
+
+    assignments = {}
+
+    # ShortSequenceException messages are written to stdout
+    # Tag these ID's as unassignable
+    for line in app_result['StdOut']:
+        excep = parse_rdp_exception(line)
+        if excep is not None:
+            _, rdp_id = excep
+            orig_id = seq_id_lookup[rdp_id]
+            assignments[orig_id] = ('Unassignable', 1.0)
     
-    # start a list to store the assignments
-    results = {}
-    
-    # iterate over the identifier, assignment strings (this is a bit
-    # of an abuse of the MinimalFastaParser, as these are not truely
-    # fasta lines)
-    for identifier, assignment_str in MinimalFastaParser(result_lines):
-        # get the original identifier from the one in the rdp result
-        identifier = identifier_lookup[\
-         identifier[:identifier.index('reverse=')].strip()]
-        # build a list to store the assignments we're confident in
-        # (i.e., the ones that have a confidence greater than min_confidence)
-        confident_assignments = []
-        # keep track of the lowest acceptable confidence value that
-        # has been encountered
-        lowest_confidence = 0.0
-        
-        # split the taxonomy assignment string
-        assignment_fields = assignment_str.split(';')
-        # iterate over (assignment, assignment confidence) pairs
-        for i in range(0,len(assignment_fields),2):
-            assignment = assignment_fields[i]
-            try:
-                assignment_confidence = float(assignment_fields[i+1])
-            except IndexError:
-                break
-            # check the confidence of the current assignment
-            if assignment_confidence >= min_confidence:
-                # if the current assignment confidence is greater than
-                # the min, store the assignment and confidence value
-                confident_assignments.append(assignment.strip())
-                lowest_confidence = assignment_confidence 
-            else:
-                # otherwise, we've made it to the lowest assignment that
-                # met the confidence threshold, so bail out of the loop
-                break
+    for line in app_result['Assignments']:
+        rdp_id, direction, taxa = parse_rdp_assignment(line)
+        orig_id = seq_id_lookup[rdp_id]
+        lineage, confidence = get_rdp_lineage(taxa, min_confidence)
+        if lineage:
+            assignments[orig_id] = (';'.join(lineage), confidence)
+        else:
+            assignments[orig_id] = ('Unclassified', 1.0)
 
-        # store the identifier, the semi-colon-separated assignments, and the
-        # confidence for the last assignment
-        results[identifier] = \
-             (';'.join(confident_assignments),lowest_confidence)
-            
     if output_fp:
         try:
-            output_file = open(output_fp,'w')
+            output_file = open(output_fp, 'w')
         except OSError:
-            raise OSError, "Can't open output file for writing: %s" % output_fp
-            
-        for seq_id, values in results.items():
-            output_file.write('%s\t%s\t%1.3f\n' % (seq_id,values[0],values[1]))
-            
+            raise OSError("Can't open output file for writing: %s" % output_fp)
+        for seq_id, assignment in assignments.items():
+            lineage, confidence = assignment
+            output_file.write(
+                '%s\t%s\t%1.3f\n' % (seq_id, lineage, confidence))
         output_file.close()
         return None
-    else:   
-        return results
+    else:
+        return assignments
 
 
 def train_rdp_classifier(training_seqs_file, taxonomy_file, model_output_dir):
@@ -609,7 +652,15 @@ def train_rdp_classifier(training_seqs_file, taxonomy_file, model_output_dir):
     Once the model data has been generated, the RDP Classifier may 
     """
     app = RdpTrainer()
-    return app(training_seqs_file, taxonomy_file, model_output_dir)
+    
+    temp_taxonomy_file = tempfile.NamedTemporaryFile(
+        prefix='RdpTaxonomy_', suffix='.txt')
+    temp_taxonomy_file.write(taxonomy_file.read())
+    temp_taxonomy_file.seek(0)
+
+    app.Parameters['taxonomy_file'] = temp_taxonomy_file.name
+    app.Parameters['model_output_dir'] = model_output_dir
+    return app(training_seqs_file)
 
 
 def train_rdp_classifier_and_assign_taxonomy(
@@ -632,14 +683,12 @@ def train_rdp_classifier_and_assign_taxonomy(
     returned.
     """
     if model_output_dir is None:
-        training_dir = mkdtemp(prefix='RdpTrainer_')
+        training_dir = tempfile.mkdtemp(prefix='RdpTrainer_')
     else:
         training_dir = model_output_dir
 
-    trainer = RdpTrainer()
-    training_results = trainer(
+    training_results = train_rdp_classifier(
         training_seqs_file, taxonomy_file, training_dir)
-
     training_data_fp = training_results['properties'].name
     assignment_results = assign_taxonomy(
         seqs_to_classify, min_confidence=min_confidence, 
@@ -651,9 +700,52 @@ def train_rdp_classifier_and_assign_taxonomy(
     return assignment_results
 
 
-if __name__ == "__main__":
-    
-    opts,args = parse_command_line_parameters()
-    assign_taxonomy(open(args[0]),min_confidence=opts.min_confidence,\
-     output_fp=opts.output_fp)
+def get_rdp_lineage(rdp_taxa, min_confidence):
+    lineage = []
+    obs_confidence = 1.0
+    for taxon, rank, confidence in rdp_taxa:
+        if confidence >= min_confidence:
+            obs_confidence = confidence
+            lineage.append(taxon)
+        else:
+            break
+    return lineage, obs_confidence
+
+
+def parse_rdp_exception(line):
+    if line.startswith('ShortSequenceException'):
+        matchobj = re.search('recordID=(\S+)', line)
+        if matchobj:
+            rdp_id = matchobj.group(1)
+            return ('ShortSequenceException', rdp_id)
+    return None
+
+
+def parse_rdp_assignment(line):
+    """Returns a list of assigned taxa from an RDP classification line
+    """
+    toks = line.strip().split('\t')
+    seq_id = toks.pop(0)
+    direction = toks.pop(0)
+    if ((len(toks) % 3) != 0):
+        raise ValueError(
+            "Expected assignments in a repeating series of (rank, name, "
+            "confidence), received %s" % toks)
+    assignments = []
+    # Fancy way to create list of triples using consecutive items from
+    # input.  See grouper function in documentation for itertools for
+    # more general example.
+    itoks = iter(toks)
+    for taxon, rank, confidence_str in zip(itoks, itoks, itoks):
+        if not taxon:
+            continue
+        assignments.append((taxon.strip('"'), rank, float(confidence_str)))
+    return seq_id, direction, assignments
+
+
+if __name__ == "__main__":    
+    opts, args = parse_command_line_parameters()
+    assign_taxonomy(
+        open(args[0]), min_confidence=opts.min_confidence,
+        output_fp=opts.output_fp)
 
