@@ -11,10 +11,10 @@ Modified from cogent.app.cd_hit.py on 1-21-10, written by Daniel McDonald.
 """
 
 __author__ = "William Walters"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["William Walters","Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.1"
 __maintainer__ = "William Walters"
 __email__ = "william.a.walters@colorado.edu"
 __status__ = "Development"
@@ -25,7 +25,8 @@ from cogent.parse.fasta import MinimalFastaParser
 from cogent.app.parameters import ValuedParameter, FlagParameter
 from cogent.app.util import CommandLineApplication, ResultPath,\
  get_tmp_filename, ApplicationError, ApplicationNotFoundError
-from cogent.util.misc import revComp
+from cogent.util.misc import remove_files
+from cogent import DNA
 
 class UclustParseError(Exception):
     pass
@@ -88,7 +89,19 @@ class Uclust(CommandLineApplication):
         # input filename, .uc format
         '--uc2clstr':ValuedParameter('--', Name='uc2clstr', Delimiter=' ',
             IsPath=True),
+
+        # Don't assume input is sorted by length (default assume sorted).
+        '--usersort':FlagParameter('--',Name='usersort'),
         
+        # Same as --maxrejects 0 --nowordcountreject.
+        # comes with a performance hit.
+        '--exact':FlagParameter('--',Name='exact'),
+
+        # Same as --maxrejects 0 --maxaccepts 0 --nowordcountreject -- 
+        # comes with a performance hit.
+        '--optimal':FlagParameter('--',Name='optimal'),
+
+        '--stable_sort':FlagParameter('--',Name='stable_sort'),
     }
      
     _suppress_stdout = False
@@ -98,7 +111,7 @@ class Uclust(CommandLineApplication):
         """ Set the input path (a fasta filepath)
         """
         # The list of values which can be passed on a per-run basis
-        allowed_values = ['--input','--uc','--fastapairs','--lib',\
+        allowed_values = ['--input','--uc','--fastapairs',\
                            '--uc2clstr','--output','--mergesort']
         
         unsupported_parameters = set(data.keys()) - set(allowed_values)
@@ -136,11 +149,20 @@ class Uclust(CommandLineApplication):
          
         return result
         
+    def _accept_exit_status(self,exit_status):
+        """ Test for acceptable exit status
+        
+            uclust can seg fault and still generate a parsable .uc file
+            so we explicitly check the exit status
+        
+        """
+        return exit_status == 0
+        
     def getHelp(self):
         """Method that points to documentation"""
         help_str =\
         """
-        UCLUST is hosted as an open source project at:
+        UCLUST is hosted at:
         http://www.drive5.com/uclust/
 
         The following papers should be cited if this resource is used:
@@ -149,29 +171,12 @@ class Uclust(CommandLineApplication):
         for uclust as of March 2010.  Cite the above URL for the time being.
         """
         return help_str
-         
-def uclust_fasta_sort_from_filepath(
-    fasta_filepath,
-    output_filepath=None,
-    HALT_EXEC=False):
-    """Generates sorted fasta file via uclust --mergesort."""
 
-    output_filepath = output_filepath or \
-     get_tmp_filename(prefix='uclust_fasta_sort', suffix='.fasta')
-    tmp_working_dir = split(output_filepath)[0]
-    
-    app = Uclust(params={'--tmpdir':tmp_working_dir},HALT_EXEC=HALT_EXEC)
-    
-    app_result = app(data={'--mergesort':fasta_filepath,\
-                           '--output':output_filepath})
-    
-    return app_result
-
-
-def get_next_hit_record(lines):
+## Start functions for processing uclust output files
+def get_next_record_type(lines,types):
     for line in lines:
         line = line.strip()
-        if line.startswith('H'):
+        if line and line[0] in types:
             yield line.split('\t')
     return
             
@@ -187,7 +192,7 @@ def get_next_two_fasta_records(lines):
 def process_uclust_pw_alignment_results(fasta_pairs_lines,uc_lines):
     """ Process results of uclust search and align """
     alignments = get_next_two_fasta_records(fasta_pairs_lines)
-    for hit in get_next_hit_record(uc_lines):
+    for hit in get_next_record_type(uc_lines,'H'):
         matching_strand = hit[4]
         if matching_strand == '-':
             strand_id = '-'
@@ -227,16 +232,105 @@ def process_uclust_pw_alignment_results(fasta_pairs_lines,uc_lines):
             
         if target_rev_match:
             query_id = uc_query_id + ' RC'
-            aligned_query = revComp(aligned_query)
+            aligned_query = DNA.rc(aligned_query)
             target_id = uc_target_id
-            aligned_target = revComp(aligned_target)
+            aligned_target = DNA.rc(aligned_target)
         else:
             query_id = uc_query_id
             aligned_query = aligned_query
             target_id = uc_target_id
             aligned_target = aligned_target
             
-        yield (query_id, target_id, aligned_query, aligned_target,percent_id)
+        yield (query_id, target_id, aligned_query, aligned_target, percent_id)
+
+def clusters_from_uc_file(uc_lines):
+    """ Given an open .uc file, return lists (clusters, failures, new_seeds)
+    
+        uc_lines: open .uc file, or similar object -- this is the output
+         generated by uclust's -uc parameter
+         
+        This function processes all hit (H), seed (S), and no hit (N) lines
+         to return all clusters, failures, and new_seeds generated in
+         a uclust run. failures should only arise when users have passed
+         --lib and --libonly, and a sequence doesn't cluster to any existing
+         reference database sequences.
+    
+    """
+    clusters = {}
+    failures = []
+    seeds = []
+    # the types of hit lines we're interested in here
+    # are hit (H), seed (S), library seed (L) and no hit (N) 
+    hit_types={}.fromkeys(list('HSNL'))
+    for record in get_next_record_type(uc_lines,hit_types):
+        hit_type = record[0]
+        # sequence identifiers from the fasta header lines only 
+        # (no comment data) are stored to identify a sequence in 
+        # a cluster -- strip off any comments here as this value
+        # is used in several places
+        query_id = record[8].split()[0]
+        target_cluster = record[9].split()[0]
+        if hit_type == 'H':
+            # add the hit to it's existing cluster (either library
+            # or new cluster)
+            clusters[target_cluster].append(query_id)
+        elif hit_type == 'S':
+            # a new seed was identified -- create a cluster with this 
+            # sequence as the first instance
+            if query_id in clusters:
+                raise UclustParseError,\
+                 ("A seq id was provided as a seed, but that seq id already "
+                  "represents a cluster. Are there overlapping seq ids in your "
+                  "reference and input files or repeated seq ids in either? "
+                  "Offending seq id is %s" % query_id)
+            clusters[query_id] = [query_id]
+            seeds.append(query_id)
+        elif hit_type == 'L':
+            # a library seed was identified -- create a cluster with this 
+            # id as the index, but don't give it any instances yet bc the hit
+            # line will be specified separately. note we need to handle these
+            # lines separately from the H lines to detect overlapping seq ids 
+            # between the reference and the input fasta files
+            if query_id in clusters:
+                raise UclustParseError,\
+                 ("A seq id was provided as a seed, but that seq id already "
+                  "represents a cluster. Are there overlapping seq ids in your "
+                  "reference and input files or repeated seq ids in either? "
+                  "Offending seq id is %s" % query_id)
+            clusters[query_id] = []
+        elif hit_type == 'N':
+            # a failure was identified -- add it to the failures list
+            failures.append(query_id)
+        else:
+            # shouldn't be possible to get here, but provided for 
+            # clarity
+            raise UclustParseError,\
+             "Unexpected result parsing line:\n%s" % '\t'.join(record)
+    
+    # will need to return the full clusters dict, I think, to support
+    # useful identifiers in reference database clustering
+    #return  clusters.values(), failures, seeds
+    return  clusters, failures, seeds
+
+## End functions for processing uclust output files
+
+
+## Start uclust convenience functions
+def uclust_fasta_sort_from_filepath(
+    fasta_filepath,
+    output_filepath=None,
+    HALT_EXEC=False):
+    """Generates sorted fasta file via uclust --mergesort."""
+    output_filepath = output_filepath or \
+     get_tmp_filename(prefix='uclust_fasta_sort', suffix='.fasta')
+    tmp_working_dir = split(output_filepath)[0]
+    
+    app = Uclust(params={'--tmpdir':tmp_working_dir},HALT_EXEC=HALT_EXEC)
+    
+    app_result = app(data={'--mergesort':fasta_filepath,\
+                           '--output':output_filepath})
+    
+    return app_result
 
 def uclust_search_and_align_from_fasta_filepath(
     query_fasta_filepath,
@@ -246,7 +340,7 @@ def uclust_search_and_align_from_fasta_filepath(
     max_accepts=8,
     max_rejects=32,
     HALT_EXEC=False):
-    """ query seqs against subject fasta using uclust
+    """ query seqs against subject fasta using uclust, 
     
        return global pw alignment of best match
     """
@@ -264,7 +358,8 @@ def uclust_search_and_align_from_fasta_filepath(
     params = {'--id':percent_ID,\
               '--maxaccepts':max_accepts,\
               '--maxrejects':max_rejects,\
-              '--libonly':True}
+              '--libonly':True,
+              '--lib':subject_fasta_filepath}
               
     if enable_rev_strand_matching:
         params['--rev'] = True
@@ -277,9 +372,8 @@ def uclust_search_and_align_from_fasta_filepath(
      get_tmp_filename(prefix='uclust_alignments',suffix='.fasta')
     uc_filepath = \
      get_tmp_filename(prefix='uclust_results',suffix='.uc')
-    input_data = {'--input':query_fasta_filepath,\
+    input_data = {'--input':query_fasta_filepath,
                   '--fastapairs':alignment_filepath,
-                  '--lib':subject_fasta_filepath,\
                   '--uc':uc_filepath}
     app_result = app(input_data)
     
@@ -298,86 +392,73 @@ def uclust_search_and_align_from_fasta_filepath(
 
 def uclust_cluster_from_sorted_fasta_filepath(
     fasta_filepath,
-    output_filepath=None, 
+    uc_save_filepath=None, 
     percent_ID=0.97, 
+    max_accepts=1,
+    max_rejects=8, 
+    optimal = False,
+    exact = False,
+    suppress_sort = False,
     enable_rev_strand_matching=False,
+    subject_fasta_filepath=None,
+    suppress_new_clusters=False,
+    stable_sort=False,
     HALT_EXEC=False):
     """ Returns clustered uclust file from sorted fasta"""
-    output_filepath = output_filepath or \
+    output_filepath = uc_save_filepath or \
      get_tmp_filename(prefix='uclust_clusters',suffix='.uc')
+     
     
-    params = {'--id':percent_ID}
-    
-    if enable_rev_strand_matching:
-        params['--rev'] = True
+    params = {'--id':percent_ID,
+              '--maxaccepts':max_accepts,
+              '--maxrejects':max_rejects}
     app = Uclust(params,HALT_EXEC=HALT_EXEC)
     
+    # Set any additional parameters specified by the user
+    if enable_rev_strand_matching: app.Parameters['--rev'].on()
+    if optimal: app.Parameters['--optimal'].on()
+    if exact: app.Parameters['--exact'].on()
+    if suppress_sort: app.Parameters['--usersort'].on()
+    if subject_fasta_filepath: app.Parameters['--lib'].on(subject_fasta_filepath)
+    if suppress_new_clusters: app.Parameters['--libonly'].on()
+    if stable_sort: app.Parameters['--stable_sort'].on()
+    
     app_result = app({'--input':fasta_filepath,'--uc':output_filepath})
     return app_result
 
-        
-def uclust_convert_uc_to_cdhit_from_filepath(
-    uc_filepath,
-    output_filepath=None,
-    HALT_EXEC=False):
-    """ Returns cdhit (.clstr) file from input uclust (.uc) file"""
-    output_filepath = output_filepath or \
-     get_tmp_filename(prefix='uclust_to_cdhit',suffix='.clstr') 
-    # prefix for tmp files should indicate what created it
-    app = Uclust(HALT_EXEC=HALT_EXEC)
-    app_result = app(data={'--uc2clstr':uc_filepath,\
-                           '--output':output_filepath })
-    return app_result
-    
-    
-def parse_uclust_clstr_file(lines):
-    """Returns a list of list of sequence ids representing clusters"""
-    clusters = []
-    curr_cluster = []
-
-    for l in lines:
-        if l.startswith('>Cluster'):
-            if not curr_cluster:
-                continue
-            clusters.append(curr_cluster)
-            curr_cluster = []
-        else:
-            # Slice off the '>' character
-            seq_label = l.split()[2][1:]
-            # Check for artifact "..." characters added by uclust
-            # Remove if found
-            if seq_label.endswith("..."):
-                seq_label = seq_label[:-3]
-            curr_cluster.append(seq_label)
-
-    if curr_cluster:
-        clusters.append(curr_cluster)
-
-    return clusters
-
 
 def get_output_filepaths(output_dir, fasta_filepath):
-    """ Returns filepaths for intermediate files to be kept """
-    
-    output_dir, output_filename = split(output_dir)
-    output_dir = output_dir or './'
-    output_file_basename, output_file_ext = splitext(fasta_filepath)
-    fasta_output_filepath = '%s/%s_sorted.fasta' % \
-     (output_dir,output_file_basename)
-    uc_output_filepath = '%s/%s_sorted.uc' % \
-     (output_dir,output_file_basename)
-    cd_hit_filepath = '%s/%s_cdhit.clstr' % \
-     (output_dir,output_file_basename)
-     
-    return fasta_output_filepath, uc_output_filepath, cd_hit_filepath, \
-     output_dir
+    """ Returns filepaths for intermediate file to be kept """
     
+    if not output_dir.endswith('/'):
+        output_dir += '/'
+        
+    output_file_basename = "".join(basename(fasta_filepath).split('.')[0:-1])
+    uc_save_filepath = '%s%s_clusters.uc' % \
+     (output_dir, output_file_basename)
+
+    return uc_save_filepath
+
+
+
 
 def get_clusters_from_fasta_filepath(
     fasta_filepath,
+    original_fasta_path,
     percent_ID=0.97,
+    max_accepts=1,
+    max_rejects=8, 
+    optimal=False,
+    exact=False,
+    suppress_sort=False,
     output_dir=None,
-    enable_rev_strand_matching=False):
+    enable_rev_strand_matching=False,
+    subject_fasta_filepath=None,
+    suppress_new_clusters=False,
+    return_cluster_maps=False,
+    stable_sort=False,
+    save_uc_files=True,
+    HALT_EXEC=False):
     """ Main convenience wrapper for using uclust to generate cluster files
     
     A source fasta file is required for the fasta_filepath.  This will be 
@@ -394,78 +475,85 @@ def get_clusters_from_fasta_filepath(
     i.e., if 99% were the parameter, all sequences that were 99% identical
     would be grouped as a cluster.
     """
+    
+
+
     # Create readable intermediate filenames if they are to be kept
-    if output_dir:
-        if not (output_dir.endswith("/")):
-            output_dir += "/"
-        fasta_output_filepath, uc_output_filepath, cd_hit_filepath, \
-         output_dir = get_output_filepaths(output_dir, fasta_filepath)
-        if not isdir(output_dir):
-            makedirs(output_dir)
+    
+    fasta_output_filepath = None
+    uc_output_filepath = None
+    cd_hit_filepath = None
+    
+    if output_dir and not output_dir.endswith('/'):
+        output_dir += '/'
+    
+    
+    if save_uc_files:
+        uc_save_filepath = get_output_filepaths(output_dir, original_fasta_path)
     else:
-        fasta_output_filepath = None
-        uc_output_filepath = None
-        cd_hit_filepath = None
-        
+        uc_save_filepath = None
+    
     sorted_fasta_filepath = ""
     uc_filepath = ""
     clstr_filepath = ""
 
 
     # Error check in case any app controller fails
+    files_to_remove = []
     try:
-        # Sort fasta input file from largest to smallest sequence 
-        sort_fasta = uclust_fasta_sort_from_filepath(fasta_filepath, \
-        fasta_output_filepath)
-        # Get sorted fasta name from application wrapper
-        sorted_fasta_filepath = sort_fasta['Output'].name
-    
+        if not suppress_sort:
+            # Sort fasta input file from largest to smallest sequence 
+            sort_fasta = uclust_fasta_sort_from_filepath(fasta_filepath, \
+            output_filepath=fasta_output_filepath)
+            
+            # Get sorted fasta name from application wrapper
+            sorted_fasta_filepath = sort_fasta['Output'].name
+            files_to_remove.append(sorted_fasta_filepath)
+        else:
+            sort_fasta = None
+            sorted_fasta_filepath = fasta_filepath
+        
         # Generate uclust cluster file (.uc format)
-        uclust_cluster = \
-         uclust_cluster_from_sorted_fasta_filepath(sorted_fasta_filepath, \
-         uc_output_filepath, percent_ID = percent_ID, \
-         enable_rev_strand_matching = enable_rev_strand_matching)
+        uclust_cluster = uclust_cluster_from_sorted_fasta_filepath(
+         sorted_fasta_filepath,
+         uc_save_filepath, 
+         percent_ID=percent_ID,
+         max_accepts=max_accepts,
+         max_rejects=max_rejects, 
+         optimal=optimal, 
+         exact=exact, 
+         suppress_sort=suppress_sort,
+         enable_rev_strand_matching=enable_rev_strand_matching,
+         subject_fasta_filepath=subject_fasta_filepath,
+         suppress_new_clusters=suppress_new_clusters,
+         stable_sort=stable_sort,
+         HALT_EXEC=HALT_EXEC)
         # Get cluster file name from application wrapper
-        uc_filepath = uclust_cluster['ClusterFile'].name
-
-        # Convert the .uc file to a cdhit (.clstr) format
-        cdhit_conversion = \
-         uclust_convert_uc_to_cdhit_from_filepath(uc_filepath, cd_hit_filepath)
-
-        # Get the open file object from the cdhit conversion wrapper
-        clstr_filepath = cdhit_conversion['Output']
     except ApplicationError:
-        if isfile(sorted_fasta_filepath):
-            remove(sorted_fasta_filepath)
-        if isfile(uc_filepath):
-            remove(uc_filepath)
-        if isfile(clstr_filepath):
-            remove(clstr_filepath)
-        raise ApplicationError, ('Error running uclust, make sure the proper '+\
-         'version (1.1.579 or greater) is installed and the input fasta file '+\
-         'is properly formatted.')
+        remove_files(files_to_remove)
+        raise ApplicationError, ('Error running uclust. Possible causes are '
+         'unsupported version (current supported version is v1.2.22) is installed or '
+         'improperly formatted input file was provided')
     except ApplicationNotFoundError:
-        if isfile(sorted_fasta_filepath):
-            remove(sorted_fasta_filepath)
-        if isfile(uc_filepath):
-            remove(uc_filepath)
-        if isfile(clstr_filepath):
-            remove(clstr_filepath)
+        remove_files(files_to_remove)
         raise ApplicationNotFoundError('uclust not found, is it properly '+\
          'installed?')
-    
+
     # Get list of lists for each cluster
-    clusters = parse_uclust_clstr_file(clstr_filepath)
+    clusters, failures, seeds = \
+     clusters_from_uc_file(uclust_cluster['ClusterFile'])
     
     # Remove temp files unless user specifies output filepath
-    if not output_dir:
-        sort_fasta.cleanUp()
+    if not save_uc_files:
+        try:
+            sort_fasta.cleanUp()
+        except AttributeError:
+            pass
         uclust_cluster.cleanUp()
-        cdhit_conversion.cleanUp()
     
-    if len(clusters) == 0:
-        raise ApplicationError, ('Clusters result empty, please check source '+\
-         'fasta file for proper formatting.')
-    
-    return clusters
+    if return_cluster_maps:
+        return clusters, failures, seeds
+    else:
+        return clusters.values(), failures, seeds
 
+## End uclust convenience functions
