@@ -6,12 +6,13 @@ NOTE: Although the genetic code objects convert DNA to RNA and vice
 versa, lists of codons that they produce will be provided in DNA format.
 """
 from string import maketrans
+import re
 
 __author__ = "Greg Caporaso and Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Greg Caporaso", "Rob Knight", "Peter Maxwell"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Greg Caporaso"
 __email__ = "caporaso@colorado.edu"
 __status__ = "Production"
@@ -136,7 +137,7 @@ class GeneticCode(object):
             else:
                 blocks.extend([[codons[2]],[codons[3]]])
             return blocks
-        
+    
     def _get_blocks(self):
         """Returns list of lists of codon blocks in the genetic code.
         
@@ -194,6 +195,7 @@ class GeneticCode(object):
         
         Returns [] for empty list of codons, 'X' for unknown amino acid.
         """
+        item = str(item)
         if len(item) == 1:  #amino acid
             return self.Synonyms.get(item, [])
         elif len(item) == 3:    #codon
@@ -219,7 +221,17 @@ class GeneticCode(object):
         if start + 1 > len(dna):
             raise ValueError, "Translation starts after end of RNA"
         return ''.join([self[dna[i:i+3]] for i in range(start, len(dna)-2, 3)])
-
+    
+    def getStopIndices(self, dna, start=0):
+        """returns indexes for stop codons in the specified frame"""
+        stops = self['*']
+        stop_pattern = '(%s)' % '|'.join(stops)
+        stop_pattern = re.compile(stop_pattern)
+        seq = str(dna)
+        found = [hit.start() for hit in stop_pattern.finditer(seq)]
+        found = [index for index in found if index % 3 == start]
+        return found
+    
     def sixframes(self, dna):
         """Returns six-frame translation as dict containing {frame:translation}
         """
