@@ -25,7 +25,7 @@ Definition of relevant terms or abbreviations:
        from a node
     -  stem: the edge immediately preceeding a clade
 """
-from numpy import zeros
+from numpy import zeros, argsort
 from copy import deepcopy
 import re
 from cogent.util.transform import comb
@@ -35,12 +35,13 @@ from cogent.util.misc import InverseDict
 from random import shuffle
 
 __author__ = "Gavin Huttley, Peter Maxwell and Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Peter Maxwell", "Rob Knight",
                     "Andrew Butterfield", "Catherine Lozupone", "Micah Hamady",
-                    "Jeremy Widmann", "Zongzhi Liu", "Daniel McDonald"]
+                    "Jeremy Widmann", "Zongzhi Liu", "Daniel McDonald",
+                    "Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -576,7 +577,41 @@ class TreeNode(object):
                 return curr
             curr = curr._parent
         return None
-    
+   
+    def lowestCommonAncestor(self, tipnames):
+        """Lowest common ancestor for a list of tipnames
+
+        This should be around O(H sqrt(n)), where H is height and n is the
+        number of tips passed in.
+        """
+        if len(tipnames) == 1:
+            return self.getNodeMatchingName(tipnames[0])
+
+        tipnames = set(tipnames)
+        tips = [tip for tip in self.tips() if tip.Name in tipnames]
+
+        if len(tips) == 0:
+            return None
+
+        for t in tips:
+            prev = t
+            curr = t.Parent
+
+            while curr and not hasattr(curr,'black'):
+                setattr(curr,'black',[prev])
+                prev = curr
+                curr = curr.Parent
+
+            # increase black count, multiple children lead to here
+            if curr:
+                curr.black.append(prev)
+
+        curr = self
+        while len(curr.black) == 1:
+            curr = curr.black[0]
+
+        return curr
+
     lca = lastCommonAncestor #for convenience
     
     #support for more advanced tree operations
@@ -991,7 +1026,54 @@ class TreeNode(object):
         
         (root_dists, endpoint_dists) = self._getDistances(endpoints)
         return endpoint_dists
-   
+
+    def setMaxTipTipDistance(self):
+        """Propagate tip distance information up the tree
+
+        This method was originally implemented by Julia Goodrich with the intent
+        of being able to determine max tip to tip distances between nodes on 
+        large trees efficiently. The code has been modified to track the 
+        specific tips the distance is between
+        """
+        for n in self.postorder():
+            if n.isTip():
+                n.MaxDistTips = [[0.0, n.Name], [0.0, n.Name]]
+            else:
+                if len(n.Children) == 1:
+                    tip_a, tip_b = n.Children[0].MaxDistTips
+                    tip_a[0] += n.Children[0].Length or 0.0
+                    tip_b[0] += n.Children[0].Length or 0.0
+                else:
+                    tip_info = [(max(c.MaxDistTips), c) for c in n.Children]
+                    dists = [i[0][0] for i in tip_info]
+                    best_idx = argsort(dists)[-2:]
+                    tip_a, child_a = tip_info[best_idx[0]]
+                    tip_b, child_b = tip_info[best_idx[1]]
+                    tip_a[0] += child_a.Length or 0.0
+                    tip_b[0] += child_b.Length or 0.0
+                n.MaxDistTips = [tip_a, tip_b]
+
+    def getMaxTipTipDistance(self):
+        """Returns the max tip tip distance between any pair of tips
+        
+        Returns (dist, tip_names, internal_node)
+        """
+        if not hasattr(self, 'MaxDistTips'):
+            self.setMaxTipTipDistance()
+
+        longest = 0.0
+        names = [None,None]
+        best_node = None
+        for n in self.nontips(include_self=True):
+            tip_a, tip_b = n.MaxDistTips
+            dist = (tip_a[0] + tip_b[0])
+
+            if dist > longest:
+                longest = dist
+                best_node = n
+                names = [tip_a[1], tip_b[1]]
+        return longest, names, best_node
+
     def maxTipTipDistance(self):
         """returns the max distance between any pair of tips
         
@@ -1001,7 +1083,7 @@ class TreeNode(object):
         max_pair = (tip_order[idx_max[0]].Name, tip_order[idx_max[1]].Name)
         return distmtx[idx_max], max_pair
  
-    def _getSubTree(self, included_names, constructor=None):
+    def _getSubTree(self, included_names, constructor=None, keep_root=False):
         """An equivalent node with possibly fewer children, or None"""
         
         # Renumber autonamed edges
@@ -1011,12 +1093,14 @@ class TreeNode(object):
         if self.Name in included_names:
             return self.deepcopy(constructor=constructor)
         else:
+            # don't need to pass keep_root to children, though
+            # internal nodes will be elminated this way
             children = [child._getSubTree(included_names, constructor)
                     for child in self.Children]
             children = [child for child in children if child is not None]
             if len(children) == 0:
                 result = None
-            elif len(children) == 1:
+            elif len(children) == 1 and not keep_root:
                 # Merge parameter dictionaries by adding lengths and making
                 # weighted averages of other parameters.  This should probably
                 # be moved out of here into a ParameterSet class (Model?) or
@@ -1041,9 +1125,18 @@ class TreeNode(object):
                 result = constructor(self, tuple(children))
         return result
     
-    def getSubTree(self, name_list, ignore_missing=False):
+    def getSubTree(self, name_list, ignore_missing=False, keep_root=False):
         """A new instance of a sub tree that contains all the otus that are
         listed in name_list.
+
+        ignore_missing: if False, getSubTree will raise a ValueError if 
+        name_list contains names that aren't nodes in the tree
+
+        keep_root: if False, the root of the subtree will be the last common
+        ancestor of all nodes kept in the subtree. Root to tip distance is
+        then (possibly) different from the original tree
+        If True, the root to tip distance remains constant, but root may only
+        have one child node.
         """
         edge_names = set(self.getNodeNames(includeself=1, tipsonly=False))
         if not ignore_missing:
@@ -1052,7 +1145,7 @@ class TreeNode(object):
                 if name not in edge_names:
                     raise ValueError("edge %s not found in tree" % name)
         
-        new_tree = self._getSubTree(name_list)
+        new_tree = self._getSubTree(name_list, keep_root=keep_root)
         if new_tree is None:
             raise TreeError, "no tree created in make sub tree"
         elif new_tree.istip():
@@ -1256,7 +1349,7 @@ class TreeNode(object):
             raise TreeError("No node named '%s' in %s" %
                     (name, self.getTipNames()))
         return node
-    
+   
     def getConnectingNode(self, name1, name2):
         """Finds the last common ancestor of the two named edges."""
         edge1 = self.getNodeMatchingName(name1)
