@@ -2,12 +2,13 @@ import sqlalchemy as sql
 
 from cogent.util import table as cogent_table
 from cogent.db.ensembl.host import DbConnection, get_db_name
+from cogent.util.misc import flatten
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007, The Cogent Project"
-__credits__ = ["Gavin Huttley"]
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
+__credits__ = ["Gavin Huttley", "Jason Merkin"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
@@ -15,12 +16,13 @@ __status__ = "alpha"
 class Database(object):
     """holds the data-base connection and table attributes"""
     def __init__(self, account, species=None, db_type=None, release=None,
-            pool_recycle=None):
+            pool_recycle=None, division=None):
         self._tables = {}
         self.db_name = get_db_name(account=account, species=species,
-                            release=release, db_type=db_type)
+                          release=release, db_type=db_type, division=division)
         if not self.db_name:
-            raise RuntimeError, "%s db doesn't exist for '%s' on '%s'" % (db_type, species, account.host)
+            raise RuntimeError, "%s db doesn't exist for '%s' on '%s'" % \
+                                        (db_type, species, account.host)
         else:
             self.db_name = self.db_name[0]
         self._db = DbConnection(account=account, db_name=self.db_name,
@@ -60,17 +62,27 @@ class Database(object):
             - column: valid values are biotype, status"""
         table = self.getTable(table_name)
         query = sql.select([table.c[column]], distinct=True)
+        records = set()
+        string_types = str, unicode
         for record in query.execute():
-            if type(record) != str:
-                new = ()
-                for value in record:
-                    if type(value) == set:
-                        value = tuple(value)
-                    new += (value,)
-                record = new
-                while len(record) == 1 and type(record) in (tuple, list):
-                    record = record[0]
-            yield record
+            if type(record) not in string_types and \
+                type(record[0]) not in string_types:
+                # multi-dimensioned list/tuple
+                record = flatten(record)
+            elif type(record) not in string_types:
+                # list/tuple of strings
+                record = tuple(record)
+            else:
+                # a string
+                record = [record]
+            
+            records.update(record)
+        return records
+    
+    def tableHasColumn(self, table_name, column):
+        """returns True if table has column"""
+        table = self.getTable(table_name)
+        return hasattr(table.c, column)
     
     def getTablesRowCount(self, table_name=None):
         """returns a cogent Table object with the row count for each table
