@@ -12,10 +12,10 @@ from cogent.db.ensembl.assembly import Coordinate, CoordSystem, \
 from cogent.db.ensembl.sequence import get_sequence
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
@@ -405,16 +405,23 @@ class Gene(_StableRegion):
         return features
     
     def getCdsLengths(self):
-        """returns the length of the transcript Cds'. If this property is not
-        available, returns None."""
+        """returns the Cds lengths from transcripts with the same biotype.
+        returns None if no transcripts."""
         if self.Transcripts is self.NULL_VALUE:
             return None
-        return [ts.getCdsLength() for ts in self.Transcripts]
+        l = [ts.getCdsLength() for ts in self.Transcripts
+                                            if ts.BioType == self.BioType]
+        return l
     
     def getLongestCdsTranscript(self):
-        """returns the Transcript with the longest Cds"""
-        result=sorted([(ts.getCdsLength(),ts) for ts in self.Transcripts])
-        return result[-1][1]
+        """returns the Transcript with the longest Cds and the same biotype"""
+        result = sorted([(ts.getCdsLength(), ts) for ts in self.Transcripts
+                                            if ts.BioType == self.BioType])
+        
+        if result: # last result is longest
+            result = result[-1][1]
+        
+        return result
     
 
 class Transcript(_StableRegion):
@@ -992,7 +999,12 @@ class Variation(_Region):
             return
         
         self._table_rows['allele_table'] = records
-        data = [(rec['allele'], rec['frequency'], rec['sample_id']) for rec in records]
+        data = [(rec['allele'], rec['frequency'], rec['sample_id'])
+                                    for rec in records if rec['sample_id']]
+        if not data:
+            self._cached[('AlleleFreqs')] = self.NULL_VALUE
+            return
+        
         table = Table(header='allele freq sample_id'.split(), rows=data)
         self._cached[('AlleleFreqs')] = table.sorted(['sample_id', 'allele'])
     
@@ -1024,15 +1036,36 @@ class Variation(_Region):
         if not 'variation_feature' in self._table_rows:
             raise NotImplementedError
         
-        if 'NON_SYNONYMOUS_CODING' not in self.Effect:
+        try:
+            effects = [self.Effect.lower()]
+        except AttributeError:
+            effects = [v.lower() for v in self.Effect]
+        
+        effects = set(effects)
+        nsyn = set(('non_synonymous_coding', 'non_synonymous_codon'))
+        if not effects & nsyn:
             self._cached['PeptideAlleles'] = self.NULL_VALUE
             self._cached['TranslationLocation'] = self.NULL_VALUE
             return
         
         table_name = self._attr_ensembl_table_map['PeptideAlleles']
         loc = lambda x: int(x)-1
+        
+        # column name changed between releases, so we check to see which
+        # one is being used for this instance and set the column strings
+        
+        # TODO can we modify the table on loading? This would give better
+        # performance.
+        
+        if self.genome.VarDb.tableHasColumn(table_name, 'pep_allele_string'):
+            pep_allele_string = 'pep_allele_string'
+            consequence_type = 'consequence_types'
+        else:
+            pep_allele_string = 'peptide_allele_string'
+            consequence_type = 'consequence_type'
+        
         attr_column_map = [
-                ('PeptideAlleles','peptide_allele_string', _quoted),
+                ('PeptideAlleles', pep_allele_string, _quoted),
                 ('TranslationLocation', 'translation_start', loc)]
         
         if table_name in self._table_rows:
@@ -1044,18 +1077,18 @@ class Variation(_Region):
         table = self.genome.VarDb.getTable(table_name)
         self_effect = set([self.Effect,[self.Effect]][type(self.Effect)==str])
         query = sql.select([table.c.variation_feature_id,
-                           table.c.peptide_allele_string,
+                           table.columns[pep_allele_string],
                            table.c.translation_start,
-                           table.c.consequence_type],
+                           table.columns[consequence_type]],
                     sql.and_(table.c.variation_feature_id == var_feature_id,
-                            table.c.peptide_allele_string != None))
+                            table.columns[pep_allele_string] != None))
         records = query.execute().fetchall()
         pep_alleles = []
         translation_location = []
         for record in records:
-            if not record['consequence_type'] & self_effect:
+            if not record[consequence_type] & self_effect:
                 continue
-            pep_alleles += [record['peptide_allele_string']]
+            pep_alleles += [record[pep_allele_string]]
             translation_location += [record['translation_start']]
         
         if not pep_alleles:
@@ -1066,8 +1099,13 @@ class Variation(_Region):
         allele_location = dict(zip(pep_alleles, translation_location))
         pep_alleles = list(set(pep_alleles))
         pep_alleles = [pep_alleles, pep_alleles[0]][len(pep_alleles)==1]
-        translation_location = allele_location[pep_alleles]
-        self._table_rows[table_name] = dict(peptide_allele_string=pep_alleles,
+        if type(pep_alleles) != str:
+            for pep_allele in pep_alleles:
+                translation_location = allele_location[pep_allele]
+        else:
+            translation_location = allele_location[pep_alleles]
+        
+        self._table_rows[table_name] = dict(pep_allele_string=pep_alleles,
                                             translation_start=translation_location)
         self._populate_cache_from_record(attr_column_map, table_name)
     
@@ -1104,7 +1142,7 @@ class CpGisland(GenericRegion):
         my_type = self.__class__.__name__
         
         return "%s(CoordName='%s'; Start=%s; End=%s; length=%s;"\
-            " Strand='%s', Score=%s)" % (my_type,
+            " Strand='%s', Score=%.1f)" % (my_type,
             self.Location.CoordName,
             self.Location.Start,
             self.Location.End,
@@ -1129,7 +1167,7 @@ class Repeat(GenericRegion):
         my_type = self.__class__.__name__
         
         return "%s(CoordName='%s'; Start=%s; End=%s; length=%s;"\
-        " Strand='%s', Score=%s)" %  (my_type,
+        " Strand='%s', Score=%.1f)" %  (my_type,
             self.Location.CoordName,
             self.Location.Start, self.Location.End, len(self),
             '-+'[self.Location.Strand>0], self.Score)
