@@ -9,10 +9,10 @@ from cogent.db.ensembl.assembly import CoordSystem, Coordinate, \
                                     get_coord_conversion
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
@@ -49,7 +49,7 @@ def get_lower_coord_conversion(coord, species, core_db):
                              seq_level=True)
     query_rank = coord_system[coord.CoordType].rank
     seq_level_rank = coord_system[seq_level_coord_type].rank
-    
+    assemblies = None
     for rank in range(query_rank+1, seq_level_rank):
         coord_type = None
         for key in coord_system.keys():
@@ -116,8 +116,11 @@ def _get_sequence_from_lower_assembly(coord, DEBUG):
         print '\nMedium_level_assemblies = ', assemblies
     
     seqs, positions = [], []
-    for q_loc, t_loc in assemblies: 
+    for q_loc, t_loc in assemblies:
+        t_strand = t_loc.Strand
         temp_seq = _get_sequence_from_direct_assembly(t_loc, DEBUG)
+        if t_strand == -1:
+            temp_seq = temp_seq.rc()
         
         if DEBUG:
             print q_loc
