@@ -2,68 +2,135 @@ from cogent.util.table import Table
 from cogent.db.ensembl.util import CaseInsensitiveString
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007, The Cogent Project"
-__credits__ = ["Gavin Huttley"]
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
+__credits__ = ["Gavin Huttley", "Jason Merkin"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
 
-_species_common_map = [['Aedes aegypti', 'A.aegypti'],
+_species_common_map = [['Acyrthosiphon pisum', 'A.pisum'],
+                       ['Aedes aegypti', 'A.aegypti'],
                        ['Anolis carolinensis', 'Anole lizard'],
-                       ['Anopheles gambiae', 'Mosquito'],
+                       ['Anopheles gambiae', 'A.gambiae'],
                        ['Apis mellifera', 'Honeybee'],
+                       ['Arabidopsis lyrata', 'A.lyrata'],
+                       ['Arabidopsis thaliana', 'A.thaliana'],
+                       ['Aspergillus clavatus', 'A.clavatus'],
+                       ['Aspergillus flavus', 'A.flavus'],
+                       ['Aspergillus fumigatus', 'A.fumigatus'],
+                       ['Aspergillus fumigatusa1163', 'A.fumigatusa1163'],
+                       ['Aspergillus nidulans', 'A.nidulans'],
+                       ['Aspergillus niger', 'A.niger'],
+                       ['Aspergillus oryzae', 'A.oryzae'],
+                       ['Aspergillus terreus', 'A.terreus'],
+                       ['Bacillus collection', 'Bacillus'],
+                       ['Borrelia collection', 'Borrelia'],
                        ['Bos taurus', 'Cow'],
+                       ['Brachypodium distachyon', 'B.distachyon'],
+                       ['Buchnera collection', 'Buchnera'],
+                       ['Caenorhabditis brenneri', 'C.brenneri'],
                        ['Caenorhabditis briggsae', 'C.briggsae'],
                        ['Caenorhabditis elegans', 'C.elegans'],
+                       ['Caenorhabditis japonica', 'C.japonica'],
+                       ['Caenorhabditis remanei', 'C.remanei'],
+                       ['Callithrix jacchus', 'Marmoset'],
                        ['Canis familiaris', 'Dog'],
                        ['Cavia porcellus', 'Guinea Pig'],
                        ['Choloepus hoffmanni', 'Sloth'],
                        ['Ciona intestinalis', 'C.intestinalis'],
                        ['Ciona savignyi', 'C.savignyi'],
+                       ['Culex quinquefasciatus', 'C.quinquefasciatus'],
                        ['Danio rerio', 'Zebrafish'],
                        ['Dasypus novemcinctus', 'Armadillo'],
+                       ['Dictyostelium discoideum', 'D.discoideum'],
                        ['Dipodomys ordii', 'Kangaroo rat'],
-                       ['Drosophila melanogaster', 'Fly'],
+                       ['Drosophila ananassae', 'D.ananassae'],
+                       ['Drosophila erecta', 'D.erecta'],
+                       ['Drosophila grimshawi', 'D.grimshawi'],
+                       ['Drosophila melanogaster', 'D.melanogaster'],
+                       ['Drosophila mojavensis', 'D.mojavensis'],
+                       ['Drosophila persimilis', 'D.persimilis'],
+                       ['Drosophila pseudoobscura', 'D.pseudoobscura'],
+                       ['Drosophila sechellia', 'D.sechellia'],
+                       ['Drosophila simulans', 'D.simulans'],
+                       ['Drosophila virilis', 'D.virilis'],
+                       ['Drosophila willistoni', 'D.willistoni'],
+                       ['Drosophila yakuba', 'D.yakuba'],
                        ['Echinops telfairi', 'Tenrec'],
                        ['Equus caballus', 'Horse'],
                        ['Erinaceus europaeus', 'Hedgehog'],
+                       ['Escherichia shigella', 'E.shigella'],
                        ['Felis catus', 'Cat'],
                        ['Gallus gallus', 'Chicken'],
                        ['Gasterosteus aculeatus', 'Stickleback'],
                        ['Gorilla gorilla', 'Gorilla'],
                        ['Homo sapiens', 'Human'],
+                       ['Ixodes scapularis', 'I.scapularis'],
                        ['Loxodonta africana', 'Elephant'],
                        ['Macaca mulatta', 'Macaque'],
                        ['Macropus eugenii', 'Wallaby'],
                        ['Microcebus murinus', 'Mouse lemur'],
                        ['Monodelphis domestica', 'Opossum'],
                        ['Mus musculus', 'Mouse'],
+                       ['Mycobacterium collection', 'Mycobacterium'],
                        ['Myotis lucifugus', 'Microbat'],
+                       ['Neisseria collection', 'Neisseria'],
+                       ['Nematostella vectensis', 'N.vectensis'],
+                       ['Neosartorya fischeri', 'N.fischeri'],
+                       ['Neurospora crassa', 'N.crassa'],
                        ['Ochotona princeps', 'Pika'],
                        ['Ornithorhynchus anatinus', 'Platypus'],
                        ['Oryctolagus cuniculus', 'Rabbit'],
+                       ['Oryza indica', 'O.indica'],
+                       ['Oryza sativa', 'O.sativa'],
                        ['Oryzias latipes', 'Medaka'],
                        ['Otolemur garnettii', 'Bushbaby'],
                        ['Pan troglodytes', 'Chimp'],
+                       ['Pediculus humanus', 'P.humanus'],
                        ['Petromyzon marinus', 'Lamprey'],
+                       ['Phaeodactylum tricornutum', 'P.tricornutum'],
+                       ['Physcomitrella patens', 'P.patens'],
+                       ['Phytophthora infestans', 'P.infestans'],
+                       ['Phytophthora ramorum', 'P.ramorum'],
+                       ['Phytophthora sojae', 'P.sojae'],
+                       ['Plasmodium berghei', 'P.berghei'],
+                       ['Plasmodium chabaudi', 'P.chabaudi'],
+                       ['Plasmodium falciparum', 'P.falciparum'],
+                       ['Plasmodium knowlesi', 'P.knowlesi'],
+                       ['Plasmodium vivax', 'P.vivax'],
                        ['Pongo pygmaeus', 'Orangutan'],
+                       ['Populus trichocarpa', 'P.trichocarpa'],
+                       ['Pristionchus pacificus', 'P.pacificus'],
                        ['Procavia capensis', 'Rock hyrax'],
                        ['Pteropus vampyrus', 'Flying fox'],
+                       ['Puccinia graministritici', 'P.graministritici'],
+                       ['Pyrococcus collection', 'Pyrococcus'],
                        ['Rattus norvegicus', 'Rat'],
                        ['Saccharomyces cerevisiae', 'S.cerevisiae'],
+                       ['Schistosoma mansoni', 'S.mansoni'],
+                       ['Schizosaccharomyces pombe', 'S.pombe'],
                        ['Sorex araneus', 'Shrew'],
+                       ['Sorghum bicolor', 'S.bicolor'],
                        ['Spermophilus tridecemlineatus', 'Ground Squirrel'],
+                       ['Staphylococcus collection', 'Staphylococcus'],
+                       ['Streptococcus collection', 'Streptococcus'],
+                       ['Strongylocentrotus purpuratus', 'S.purpuratus'],
                        ['Sus scrofa', 'Pig'],
                        ['Taeniopygia guttata', 'Zebra finch'],
                        ['Takifugu rubripes', 'Fugu'],
                        ['Tarsius syrichta', 'Tarsier'],
                        ['Tetraodon nigroviridis', 'Tetraodon'],
+                       ['Thalassiosira pseudonana', 'T.pseudonana'],
+                       ['Trichoplax adhaerens', 'T.adhaerens'],
                        ['Tupaia belangeri', 'Tree Shrew'],
                        ['Tursiops truncatus', 'Bottlenose dolphin'],
                        ['Vicugna pacos', 'Alpaca'],
-                       ['Xenopus tropicalis', 'Xenopus']]
+                       ['Vitis vinifera', 'V.vinifera'],
+                       ['Wolbachia collection', 'Wolbachia'],
+                       ['Xenopus tropicalis', 'Xenopus'],
+                       ['Zea mays', 'Z.mays']]
 
 class SpeciesNameMap(dict):
     """mapping between common names and latin names"""
@@ -145,6 +212,18 @@ class SpeciesNameMap(dict):
         
         return str(species_name.lower().replace(" ","_"))
     
+    def getComparaName(self, name):
+        """returns string matching a compara instance attribute name for a
+        species"""
+        name = self.getCommonName(name)
+        if '.' in name:
+            name = name.replace('.', '')
+        else:
+            name = name.title()
+        
+        name = name.split()
+        return ''.join(name)
+    
     def _purge_species(self, species_name):
         """removes a species record"""
         species_name = CaseInsensitiveString(species_name)
