@@ -2,17 +2,17 @@
 
 __all__ = ["best_likelihood", "bootstrap", "likelihood_calculation",
            "likelihood_function", "likelihood_tree", "models",
-           "parameter_controller", "predicate", "simulate",
-           "substitution_calculation", "substitution_model",
+           "pairwise_distance", "parameter_controller", "predicate",
+           "simulate", "substitution_calculation", "substitution_model",
            "coevolution"]
 
 __author__ = ""
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Peter Maxwell", "Andrew Butterfield",
                     "Rob Knight", "Matthrew Wakefield", "Brett Easton", 
                     "Edward Lang","Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
