@@ -6,10 +6,10 @@ from cogent.recalculation.definition import (NonParamDefn, CalcDefn,
     DictArrayTemplate)
     
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -36,12 +36,12 @@ class PsubMatrixDefn(PartitionDefn):
         diag = numpy.identity(self.size, float)
         return (flat + diag) / 2
 
-    def checkValueIsValid(self, value, is_const):
+    def checkValueIsValid(self, value, is_constant):
         if value.shape != (self.size,self.size):
             raise ValueError("Wrong array shape %s for %s, expected (%s,%s)" % 
                     (value.shape, self.name, self.size, self.size))
         for part in value:
-            PartitionDefn.checkValueIsValid(self, part, is_const)
+            PartitionDefn.checkValueIsValid(self, part, is_constant)
     
     def makeCells(self, input_soup={}, variable=None):
         uniq_cells = []
@@ -55,7 +55,7 @@ class PsubMatrixDefn(PartitionDefn):
             assert value.shape == (self.size,self.size)
             scope = [key for key in self.assignments
                     if self.assignments[key] is v]
-            if v.is_const or (variable is not None and variable is not v):
+            if v.is_constant or (variable is not None and variable is not v):
                 matrix = ConstCell(self.name, value)
             else:
                 rows = []
