@@ -33,6 +33,7 @@ called Q) is determined.
 import numpy
 from numpy.linalg import svd
 import warnings
+import inspect
 
 from cogent.core import moltype
 from cogent.evolve import parameter_controller, predicate, motif_prob_model
@@ -41,18 +42,18 @@ from cogent.evolve.substitution_calculation import (
     RateDefn, LengthDefn, ProductDefn, CallDefn, CalcDefn,
     PartitionDefn, NonParamDefn, AlignmentAdaptDefn, ExpDefn, 
     ConstDefn, GammaDefn, MonotonicDefn, SelectForDimension, 
-    WeightedPartitionDefn, chooseFastExponentiators)
+    WeightedPartitionDefn)
 from cogent.evolve.discrete_markov import PsubMatrixDefn
 from cogent.evolve.likelihood_tree import makeLikelihoodTreeLeaf
-from cogent.maths.optimiser import ParameterOutOfBoundsError
+from cogent.maths.optimisers import ParameterOutOfBoundsError
 
 __author__ = "Peter Maxwell, Gavin Huttley and Andrew Butterfield"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __contributors__ = ["Gavin Huttley", "Andrew Butterfield", "Peter Maxwell",
                     "Matthew Wakefield", "Brett Easton", "Rob Knight",
                     "Von Bing Yap"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -87,20 +88,12 @@ def _maxWidthIfTruncated(pars, delim, each):
             + len(delim) * (len(par_list)-1)
         for par_list in pars.flat])
 
-def _extract_kw(substring, kw):
-    """move any keys containg substring into a new dictionary"""
-    mkw = {}
-    for k in kw.keys():
-        if substring in k:
-            mkw[k] = kw.pop(k)
-    return mkw
-
 def _isSymmetrical(matrix):
     return numpy.alltrue(numpy.alltrue(matrix == numpy.transpose(matrix)))
 
 def extend_docstring_from(cls, pre=False): 
     def docstring_inheriting_decorator(fn):
-        parts = [getattr(cls,fn.__name__).__doc__, fn.__doc__]
+        parts = [getattr(cls,fn.__name__).__doc__, fn.__doc__ or '']
         if pre: parts.reverse()
         fn.__doc__ = ''.join(parts) 
         return fn 
@@ -109,15 +102,13 @@ def extend_docstring_from(cls, pre=False):
 class _SubstitutionModel(object):
     # Subclasses must provide
     #  .makeParamControllerDefns()
-    _scalableQ = False
     
     def __init__(self, alphabet, 
             motif_probs=None, optimise_motif_probs=False,
             equal_motif_probs=False, motif_probs_from_data=None,
             motif_probs_alignment=None, mprob_model=None,  
             model_gaps=False, recode_gaps=False, motif_length=None,
-            name="", motifs=None, do_scaling=None,
-            **kw):
+            name="", motifs=None):
         # subclasses can extend this incomplete docstring
         """
          
@@ -143,9 +134,6 @@ class _SubstitutionModel(object):
          - mprob_model: 'tuple', 'conditional' or 'monomer' to specify how
            tuple-alphabet (including codon) motif probs are used.
            
-        Substitution Rate:
-         - do_scaling: Scale branch lengths as the expected number of 
-           substitutions.  Reduces the maximum substitution df by 1.
         """
             
         # MISC
@@ -155,12 +143,6 @@ class _SubstitutionModel(object):
         self.name = name
         self._optimise_motif_probs = optimise_motif_probs
         
-        if do_scaling is None:
-            do_scaling = self._scalableQ
-        if do_scaling and not self._scalableQ:
-            raise ValueError("Can't autoscale a %s model" % type(self).__name__)
-        self._do_scaling = do_scaling
-        
         # ALPHABET        
         if recode_gaps:
             if model_gaps:
@@ -185,14 +167,11 @@ class _SubstitutionModel(object):
         
         # MOTIF PROB ALPHABET MAPPING
         if mprob_model is None:
-            mprob_model = 'tuple' # 'conditional' in future
-            if self._word_length > 1:
-                warnings.warn('Default mprob_model will change to "conditional"'
-                    ' in version 1.5, so specify mprob_model="tuple"',
-                    stacklevel=4)
+            mprob_model = 'tuple' if self._word_length==1 else 'conditional'
         elif mprob_model == 'word':
             mprob_model = 'tuple'
-        elif model_gaps and mprob_model != 'tuple':
+        
+        if model_gaps and mprob_model != 'tuple':
             raise ValueError("mprob_model must be 'tuple' to model gaps")
         
         isinst = self._isInstantaneous
@@ -223,12 +202,7 @@ class _SubstitutionModel(object):
             if motif_probs_from_data is None:
                 motif_probs_from_data = True
         self.motif_probs_from_align = motif_probs_from_data
-        
-        self.setupSubstitutionParams(**kw)
- 
-    def setupSubstitutionParams(self):
-        pass
-            
+         
     def getParamList(self):
         return []
     
@@ -286,7 +260,7 @@ class _SubstitutionModel(object):
         result = klass(self, tree, **kw)
         
         if self.motif_probs is not None:
-            result.setMotifProbs(self.motif_probs, is_const=
+            result.setMotifProbs(self.motif_probs, is_constant=
                 not optimise_motif_probs, auto=True)
         
         if expm is None:
@@ -343,13 +317,29 @@ class _SubstitutionModel(object):
     def calcWordWeightMatrix(self, monomer_probs):
         return self.mprob_model.calcWordWeightMatrix(monomer_probs)
     
-    def makeParamControllerDefns(self, bin_names):
-        defns = self.makeFundamentalParamControllerDefns(bin_names)
-        model = ConstDefn(self, 'model')
-        defns.update({
-            'align': self.makeAlignmentDefn(model),
-            'psubs': self.makePsubsDefn(**defns),
-            })
+    def makeParamControllerDefns(self, bin_names, endAtQd=False):
+        (input_probs, word_probs, mprobs_matrix) = \
+                self.mprob_model.makeMotifWordProbDefns()
+
+        if len(bin_names) > 1:
+            bprobs = PartitionDefn(
+                [1.0/len(bin_names) for bin in bin_names], name = "bprobs",
+                dimensions=['locus'], dimension=('bin', bin_names))
+        else:
+            bprobs = None
+        
+        defns = {
+            'align': self.makeAlignmentDefn(ConstDefn(self, 'model')),
+            'bprobs': bprobs,
+            'word_probs': word_probs,
+             }
+        
+        rate_params = self.makeRateParams(bprobs)
+        if endAtQd:
+            defns['Qd'] = self.makeQdDefn(word_probs, mprobs_matrix, rate_params)
+        else:
+            defns['psubs'] = self.makePsubsDefn(
+                    bprobs, word_probs, mprobs_matrix, rate_params)
         return defns
 
 
@@ -362,36 +352,23 @@ class DiscreteSubstitutionModel(_SubstitutionModel):
     def getParamList(self):
         return []
         
-    def makePsubsDefn(self, **kw):
+    def makeRateParams(self, bprobs):
+        return []
+
+    def makePsubsDefn(self, bprobs, word_probs, mprobs_matrix, rate_params):
+        assert len(rate_params) == 0
+        assert word_probs is mprobs_matrix, "Must use simple mprob model"
         motifs = tuple(self.getAlphabet())
-        psub = PsubMatrixDefn(
+        return PsubMatrixDefn(
             name="psubs", dimension = ('motif', motifs), default=None, 
             dimensions=('locus', 'edge'))
-        return psub
         
-    def makeFundamentalParamControllerDefns(self, bin_names):                
-        (input_probs, word_probs, mprobs_matrix) = \
-                self.mprob_model.makeMotifWordProbDefns()
-        
-        # XXX absorb 1 unneeded input
-        word_probs = CalcDefn(
-                lambda x,y:x, name='hack')(
-                word_probs, mprobs_matrix)
-        
-        defns = {
-            'motif_probs': input_probs,  
-            'word_probs': word_probs,
-            'bprobs': None,
-            }
-        return defns
-
 
 class _ContinuousSubstitutionModel(_SubstitutionModel):
     # subclass must provide:
     #
-    # - setupSubstitutionParams()
-    #   use alphabet, do_scaling and instantaneous_mask to set up any params.
-    #   setting at least self.parameter_order
+    # - parameter_order: a list of parameter names corresponding to the 
+    #   arguments of:
     # 
     # - calcExchangeabilityMatrix(*params)
     #   convert len(self.parameter_order) params to a matrix
@@ -409,12 +386,9 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
     _exponentiator = None
     _default_expm_setting = 'either'
     
-    def setupSubstitutionParams(self):
-        self.parameter_order = []
-
     @extend_docstring_from(_SubstitutionModel)
     def __init__(self, alphabet, with_rate=False, ordered_param=None, 
-            distribution=None, partitioned_params=None, **kw):
+            distribution=None, partitioned_params=None, do_scaling=None, **kw):
 
         """
          - with_rate: Add a 'rate' parameter which varies by bin. 
@@ -422,11 +396,19 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
          - distribution: choices of 'free' or 'gamma' or an instance of some
            distribution. Could probably just deprecate free
          - partitioned_params: names of params to be partitioned across bins
+         - do_scaling: Scale branch lengths as the expected number of 
+           substitutions.  Reduces the maximum substitution df by 1.
         """
         
         _SubstitutionModel.__init__(self, alphabet, **kw)
         alphabet = self.getAlphabet() # as may be altered by recode_gaps etc.
                
+        if do_scaling is None:
+            do_scaling = self._scalableQ
+        if do_scaling and not self._scalableQ:
+            raise ValueError("Can't autoscale a %s model" % type(self).__name__)
+        self._do_scaling = do_scaling
+        
         # BINS
         if not ordered_param:
             if ordered_param is not None:
@@ -461,11 +443,6 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
         if self.ordered_param:
             if self.ordered_param not in partitioned_params:
                 partitioned_params += (self.ordered_param,)
-        
-        for param in partitioned_params:
-            if param not in self.parameter_order and param != 'rate':
-                desc = ['partitioned', 'ordered'][param==ordered_param]
-                raise ValueError('%s param "%s" unknown' % (desc, param))
         self.partitioned_params = partitioned_params
         
         if 'rate' in partitioned_params:
@@ -476,6 +453,14 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
         self._exponentiator = None
         #self._ident = numpy.identity(len(self.alphabet), float)
         
+    def checkParamsExist(self):
+        """Raise an error if the parameters specified to be partitioned or
+        ordered don't actually exist."""
+        for param in self.partitioned_params:
+            if param not in self.parameter_order and param != 'rate':
+                desc = ['partitioned', 'ordered'][param==self.ordered_param]
+                raise ValueError('%s param "%s" unknown' % (desc, param))
+
     def _isInstantaneous(self, x, y):
         diffs = sum([X!=Y for (X,Y) in zip(x,y)])
         return diffs == 1 or (diffs > 1 and
@@ -504,38 +489,22 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
         return True
     
     def calcQ(self, word_probs, mprobs_matrix, *params):
-        R = self.calcExchangeabilityMatrix(word_probs, *params)
-        sum = numpy.sum
-        Q = R * mprobs_matrix
-        row_totals = sum(Q, axis=1)
+        Q = self.calcExchangeabilityMatrix(word_probs, *params)
+        Q *= mprobs_matrix
+        row_totals = Q.sum(axis=1)
         Q -= numpy.diag(row_totals)
         if self._do_scaling:
-            scale = 1.0 / sum(word_probs * row_totals)
-            Q *= scale
+            Q *= 1.0 / (word_probs * row_totals).sum()
         return Q
     
     def makeQdDefn(self, word_probs, mprobs_matrix, rate_params):
+        """Diagonalized Q, ie: rate matrix prepared for exponentiation"""
         Q = CalcDefn(self.calcQ, name='Q')(word_probs, mprobs_matrix, *rate_params)
         expm = NonParamDefn('expm')
-        exp = ExpDefn(expm, model=self)
+        exp = ExpDefn(expm)
         Qd = CallDefn(exp, Q, name='Qd')
         return Qd
     
-    def makeSubstitutionDefns(self, bprobs):
-        (input_probs, word_probs, mprobs_matrix) = \
-                self.mprob_model.makeMotifWordProbDefns()
-                
-        rate_params = self.makeRateParams(bprobs)
-        Qd = self.makeQdDefn(word_probs, mprobs_matrix, rate_params)
-        
-        defns = {
-            'motif_probs': input_probs,  
-            'word_probs': word_probs,
-            'mprobs_matrix': mprobs_matrix,
-            'Qd': Qd,
-             }
-        return defns    
-
     def _makeBinParamDefn(self, edge_par_name, bin_par_name, bprob_defn):
         # if no ordered param defined, behaves as old, everything indexed by and edge
         if edge_par_name not in self.partitioned_params:
@@ -565,52 +534,33 @@ class _ContinuousSubstitutionModel(_SubstitutionModel):
             params.append(defn)
         return params
 
-    def makeLengthDefns(self, bprobs):
+    def makeFundamentalParamControllerDefns(self, bin_names):
+        """Everything one step short of the psubs, because cogent.align code
+        needs to handle Q*t itself."""
+        defns = self.makeParamControllerDefns(bin_names, endAtQd=True)
+        assert not 'length' in defns
+        defns['length'] = LengthDefn()
+        return defns
+        
+    def makePsubsDefn(self, bprobs, word_probs, mprobs_matrix, rate_params):
+        distance = self.makeDistanceDefn(bprobs)
+        P = self.makeContinuousPsubDefn(word_probs, mprobs_matrix, distance, rate_params)
+        return P
+        
+    def makeDistanceDefn(self, bprobs):
         length = LengthDefn()
         if self.with_rate and bprobs is not None:
             b_rate = self._makeBinParamDefn('rate', 'rate', bprobs)
             distance = ProductDefn(length, b_rate, name="distance")
         else:
             distance = length
-        return {'length':length, 'distance':distance}               
-    
-    def makeFundamentalParamControllerDefns(self, bin_names):
-        """Everything one step short of the psubs, because cogent.align code
-        needs to handle Q*t itself"""
-        if len(bin_names) > 1:
-            bprobs = PartitionDefn(
-                [1.0/len(bin_names) for bin in bin_names], name = "bprobs",
-                dimensions=['locus'], dimension=('bin', bin_names))
-        else:
-            bprobs = None
-        defns = self.makeSubstitutionDefns(bprobs)
+        return distance
         
-        defns.update(self.makeLengthDefns(bprobs))
-        defns['bprobs'] = bprobs
-        return defns
-        
-    def makePsubsDefn(self, Qd, distance, **kw):
-        """Makes the second part of the parameter controller definition,
-        psubs given motif probs and lengths"""
-        return CallDefn(Qd, distance, 
-                name='psubs')
+    def makeContinuousPsubDefn(self, word_probs, mprobs_matrix, distance, rate_params):
+        Qd = self.makeQdDefn(word_probs, mprobs_matrix, rate_params)
+        P = CallDefn(Qd, distance, name='psubs')
+        return P
     
-    def suitableEigenExponentiators(self):
-        # Uses a fake Q to compare the eigenvalue implementations
-        # with.  This assumes that one Q will be much like another.
-        if self._exponentiator is None:
-            import random
-            params = [random.uniform(0.8, 1.2) for p in self.parameter_order]
-            if self.motif_probs:
-                motif_probs = self.motif_probs
-            else:
-                motif_probs = self.mprob_model.makeSampleMotifProbs()
-            monomer_probs = self.adaptMotifProbs(motif_probs, auto=True)
-            word_probs = self.calcWordProbs(monomer_probs)
-            mprobs_matrix = self.calcWordWeightMatrix(monomer_probs)
-            sampleQ = self.calcQ(word_probs, mprobs_matrix, *params)
-            self._exponentiator = chooseFastExponentiators(sampleQ)
-        return self._exponentiator
 
 class General(_ContinuousSubstitutionModel):
     """A continuous substitution model with one free parameter for each and 
@@ -621,8 +571,11 @@ class General(_ContinuousSubstitutionModel):
     # k<=N:   apply Kth exchangeability parameter
     # k==N+1: no parameter, should be 1.0 in unscaled Q
 
-    def setupSubstitutionParams(self):
-        alphabet = self.getAlphabet()
+    #@extend_docstring_from(_ContinuousSubstitutionModel)
+    def __init__(self, alphabet, **kw):
+        _ContinuousSubstitutionModel.__init__(self, alphabet, **kw)
+
+        alphabet = self.getAlphabet() # as may be altered by recode_gaps etc.
         mask = self._instantaneous_mask
         N = len(alphabet)
         self.param_pick = numpy.zeros([N,N], int)
@@ -635,7 +588,8 @@ class General(_ContinuousSubstitutionModel):
         if self._do_scaling:
             const_param = self.parameter_order.pop()
         self.symmetric = False
-    
+        self.checkParamsExist()
+        
     def calcExchangeabilityMatrix(self, mprobs, *params):
         return numpy.array((0.0,)+params+(1.0,)).take(self.param_pick)
 
@@ -644,8 +598,11 @@ class GeneralStationary(_ContinuousSubstitutionModel):
     every possible instantaneous substitution, except the last in each column.
     As general as can be while still having stationary motif probabilities"""
     
-    def setupSubstitutionParams(self):
-        alphabet = self.getAlphabet()
+    #@extend_docstring_from(_ContinuousSubstitutionModel)
+    def __init__(self, alphabet, **kw):
+        _ContinuousSubstitutionModel.__init__(self, alphabet, **kw)
+
+        alphabet = self.getAlphabet() # as may be altered by recode_gaps etc.
         mask = self._instantaneous_mask
         N = len(alphabet)
         self.param_pick = numpy.zeros([N,N], int)
@@ -667,6 +624,7 @@ class GeneralStationary(_ContinuousSubstitutionModel):
         if self._do_scaling:
             const_param = self.parameter_order.pop()
         self.symmetric = False
+        self.checkParamsExist()
 
     def calcExchangeabilityMatrix(self, mprobs, *params):
         R = numpy.array((0.0,)+params+(1.0,)).take(self.param_pick)
@@ -689,11 +647,9 @@ class Empirical(_ContinuousSubstitutionModel):
         """
          - rate_matrix: The instantaneous rate matrix
         """
-        _ContinuousSubstitutionModel.__init__(self, alphabet, 
-                rate_matrix=rate_matrix, **kw)
+        _ContinuousSubstitutionModel.__init__(self, alphabet, **kw)
     
-    def setupSubstitutionParams(self, rate_matrix):
-        alphabet = self.getAlphabet()
+        alphabet = self.getAlphabet()  # as may be altered by recode_gaps etc.
         N = len(alphabet)
         assert rate_matrix.shape == (N, N)
         assert numpy.alltrue(numpy.diagonal(rate_matrix) == 0)
@@ -701,26 +657,26 @@ class Empirical(_ContinuousSubstitutionModel):
         self._instantaneous_mask = (self._instantaneous_mask_f != 0.0)
         self.symmetric = _isSymmetrical(self._instantaneous_mask_f)
         self.parameter_order = []
+        self.checkParamsExist()
 
     def calcExchangeabilityMatrix(self, mprobs):
         return self._instantaneous_mask_f.copy()
 
+
 class SubstitutionModel(_ContinuousSubstitutionModel):
     """A continuous substitution model with only user-specified substitution
     parameters."""
     
     @extend_docstring_from(_ContinuousSubstitutionModel)
-    def __init__(self, alphabet, predicates=None, **kw):
+    def __init__(self, alphabet, predicates=None, scales=None, **kw):
         """
          - predicates: a dict of {name:predicate}. See cogent.evolve.predicate
+         - scales: scale rules, dict with predicates
         """
-#         - scales: scale rules, dict with predicates
         self._canned_predicates = None
-        _ContinuousSubstitutionModel.__init__(self, alphabet, 
-                predicates=predicates, **kw)
+        _ContinuousSubstitutionModel.__init__(self, alphabet, **kw)
 
-    def setupSubstitutionParams(self, predicates, scales=None):
-        predicate_masks = self._adaptPredicates(predicates or [])
+        (predicate_masks, predicate_order) = self._adaptPredicates(predicates or [])
 
         # Check for redundancy in predicates, ie: 1 or more than combine
         # to be equivalent to 1 or more others, or the distance params.
@@ -750,26 +706,24 @@ class SubstitutionModel(_ContinuousSubstitutionModel):
         self.parameter_order = []
         self.predicate_indices = []
         self.symmetric = _isSymmetrical(self._instantaneous_mask)
-        for (pred, mask) in predicate_masks.items():
+        for pred in predicate_order:
+            mask = predicate_masks[pred]
             if not _isSymmetrical(mask):
                 self.symmetric = False
-            indices = numpy.nonzero(mask.ravel())[0]
-            assert numpy.alltrue(numpy.take(mask.flat, indices, 0) == 1)
+            indices = numpy.nonzero(mask)
+            assert numpy.alltrue(mask[indices] == 1)
             self.parameter_order.append(pred)
             self.predicate_indices.append(indices)
         if not self.symmetric:
             warnings.warn('Model not reversible')
-
-        self.scale_masks = self._adaptPredicates(scales or [])
+        (self.scale_masks, scale_order) = self._adaptPredicates(scales or [])
+        self.checkParamsExist()
             
     def calcExchangeabilityMatrix(self, mprobs, *params):
         assert len(params) == len(self.predicate_indices), self.parameter_order
         R = self._instantaneous_mask_f.copy()
-        work = numpy.ones(R.shape, float)
         for (indices, par) in zip(self.predicate_indices, params):
-            numpy.put(work, indices, par)
-            R *= work
-            work[:] = 1.0
+            R[indices] *= par
         return R
     
     def asciiArt(self, delim='', delim2='|', max_width=70):
@@ -854,7 +808,7 @@ class SubstitutionModel(_ContinuousSubstitutionModel):
         return self._isInstantaneous(x, y)
     
     def getSubstitutionRateValueFromQ(self, Q, motif_probs, pred):
-        pred_mask = self._adaptPredicates([pred]).values()[0]
+        pred_mask = self._adaptPredicates([pred])[0].values()[0]
         pred_row_totals = numpy.sum(pred_mask * Q, axis=1)
         inst_row_totals = numpy.sum(self._instantaneous_mask * Q, axis=1)
         r = sum(pred_row_totals * motif_probs)
@@ -899,12 +853,14 @@ class SubstitutionModel(_ContinuousSubstitutionModel):
         else:
             rules = [(None, rule) for rule in rules]
         predicate_masks = {}
+        order = []
         for (key, pred) in rules:
             (label, mask) = self.adaptPredicate(pred, key)
             if label in predicate_masks:
                 raise KeyError('Duplicate predicate name "%s"' % label)
             predicate_masks[label] = mask
-        return predicate_masks
+            order.append(label)
+        return predicate_masks, order
     
     def adaptPredicate(self, pred, label=None):
         if isinstance(pred, str):
