@@ -10,11 +10,11 @@ import textwrap
 from cogent.util.warning import discontinued
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Peter Maxwell", "Matthew Wakefield",
                     "Jeremy Widmann"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -200,10 +200,11 @@ def simpleFormat(header, formatted_table, title = None, legend = None, max_width
             if start > identifiers: # we are doing a sub-table
                 table.append("continued: %s" % title)
             
+            subhead = space.join([space.join(header[:identifiers]),
+                    space.join(header[start: end])])
+            width = len(subhead)
             table.append("=" * width)
-            subhead = [space.join(header[:identifiers]),
-                    space.join(header[start: end])]
-            table.append(space.join(subhead))
+            table.append(subhead)
             table.append("-" * width)
             for row in formatted_table:
                 row = [space.join(row[:identifiers]),
@@ -472,7 +473,7 @@ def formattedCells(rows, header = None, digits=4, column_templates = None, missi
             elif isinstance(entry, float):
                 entry = float_template % float(entry)
             else: # for any other python object
-                entry = '%s' % entry
+                entry = '%s' % str(entry)
             
             formatted.append(entry)
             col_widths[cdex] = max(col_widths[cdex], len(entry))
