@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
-__all__ = ['function_optimisation',
+__all__ = ['fit_function'
+           'function_optimisation',
            'geometry',
            'markov',
            'matrix_exponentiation',
@@ -16,11 +17,11 @@ __all__ = ['function_optimisation',
 
 
 __author__ = ""
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Peter Maxwell", "Matthew Wakefield",
-                    "Rob Knight", "Edward Lang", "Sandra Smit"]
+                    "Rob Knight", "Edward Lang", "Sandra Smit", "Antonio Gonzalez Pena"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
