@@ -64,11 +64,12 @@ from numpy import (array, zeros, logical_and, logical_or, logical_xor, where,
 from numpy.linalg import norm
 
 __author__ = "Justin Kuczynski"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Rob Knight", "Micah Hamady", "Justin Kuczynski",
-                    "Zongzhi Liu", "Catherine Lozupone", "Antonio Gonzalez Pena"]
+                    "Zongzhi Liu", "Catherine Lozupone", 
+                    "Antonio Gonzalez Pena", "Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 __status__ = "Prototype"
@@ -245,7 +246,7 @@ def dist_canberra(datamtx, strict=True):
         except ValueError:
             return zeros((0,0),'d')
 
-    oldstate = seterr(divide='ignore')
+    oldstate = seterr(invalid='ignore',divide='ignore')
     if numrows == 0 or numcols == 0:
         return zeros((0,0),'d')
     dists = zeros((numrows,numrows),'d')
@@ -612,6 +613,77 @@ def dist_manhattan(datamtx, strict=True):
             
     return dists
 
+def dist_abund_jaccard(datamtx, strict=True):
+    """Calculate abundance-based Jaccard distance between rows
+
+    The abundance-based Jaccard index is defined in Chao et. al.,
+    Ecology Lett. 8, 148 (2005), eq. 5:
+
+    J_abd = UV / (U + V - UV), where
+
+    U = sum of relative abundances of shared species in a
+    V = sum of relative abundances of shared species in b
+
+    The Chao-Jaccard distance is 1 - J_abd
+    
+    * comparisons are between rows (samples)
+    * input: 2D numpy array.  Limited support for non-2D arrays if 
+    strict==False
+    * output: numpy 2D array float ('d') type.  shape (inputrows, inputrows)
+    for sane input data
+    * two rows of all zeros returns 0 distance between them
+    * an all zero row compared with a not all zero row returns a distance of 1
+    * if strict==True, raises ValueError if any of the input data is negative,
+    not finite, or if the input data is not a rank 2 array (a matrix).
+    * if strict==False, assumes input data is a matrix with nonnegative 
+    entries.  If rank of input data is < 2, returns an empty 2d array (shape:
+    (0, 0) ).  If 0 rows or 0 colunms, also returns an empty 2d array.
+    """
+    if strict:
+        if not all(isfinite(datamtx)):
+            raise ValueError("non finite number in input matrix")
+        if any(datamtx<0.0):
+            raise ValueError("negative value in input matrix")
+        if rank(datamtx) != 2:
+            raise ValueError("input matrix not 2D")
+        numrows, numcols = shape(datamtx)
+    else:
+        try:
+            numrows, numcols = shape(datamtx)
+        except ValueError:
+            return zeros((0,0),'d')
+
+    if numrows == 0 or numcols == 0:
+        return zeros((0,0),'d')
+    dists = zeros((numrows,numrows),'d')
+    
+    rowsums = datamtx.sum(axis=1, dtype='float')
+
+    for i in range(numrows):
+        row1 = datamtx[i]
+        N1 = rowsums[i]
+
+        for j in range(i):
+            row2 = datamtx[j]
+            N2 = rowsums[j]
+
+            if N1 == 0.0 and N2 == 0.0:
+                similarity = 1.0
+            elif N1 == 0.0 or N2 == 0.0:
+                similarity = 0.0
+            else:
+                shared = logical_and(row1, row2)
+                u = sum(row1[shared]) / N1
+                v = sum(row2[shared]) / N2
+                # Verified by graphical inspection
+                if u == 0.0 and v == 0.0:
+                    similarity = 0.0
+                else:
+                    similarity = (u * v) / (u + v - (u * v))
+
+            dists[i][j] = dists[j][i] = 1 - similarity
+    return dists
+
 def dist_morisita_horn(datamtx, strict=True):
     """ returns morisita-horn distance between rows
 
@@ -903,6 +975,26 @@ def dist_specprof(datamtx, strict=True):
 
     return dists
 
+def binary_dist_otu_gain(otumtx):
+    """ Calculates number of new OTUs observed in sample A wrt sample B
+    
+        This is an non-phylogenetic distance matrix analagous to unifrac_g. 
+        The number of OTUs gained in each sample is computed with respect to
+        each other sample.
+    
+    """
+    result = []
+    for i in otumtx:
+        row = []
+        for j in otumtx:
+            gain = 0
+            for i_val, j_val in zip(i, j):
+                if i_val > 0 and j_val == 0:
+                    gain += 1
+            row.append(gain)
+        result.append(row)
+    return array(result)
+
 def binary_dist_chisq(datamtx, strict=True):
     """Calculates binary chi-square dist between rows, returns dist matrix.
 
