@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 
 __author__ = "Matthew Wakefield"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Matthew Wakefield", "Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Matthew Wakefield"
-__email__ = "matthew.wakefield@anu.edu.au"
+__email__ = "wakefield@wehi.edu.au"
 __status__ = "Production"
 
 import warnings
@@ -35,9 +35,9 @@ def MsfParser(f):
     sequences = {}
     for line in f:
         line = line.strip().split()
-        if line and sequences.has_key(line[0]):
+        if line and line[0] in sequences:
             sequences[line[0]] += ''.join(line[1:])
-        elif line and seqinfo.has_key(line[0]):
+        elif line and line[0] in seqinfo:
             sequences[line[0]] = ''.join(line[1:])
     #consistency check
     if len(sequences) != len(seqinfo):
