@@ -9,11 +9,11 @@ from cogent.core.annotation import Feature
 from cogent.core.info import Info
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Rob Knight", "Peter Maxwell", "Matthew Wakefield",
                     "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.4.1"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
@@ -575,7 +575,12 @@ def RichGenbankParser(handle, info_excludes=None, moltype=None,
                                         Name=rec['locus'])
         except KeyError:
             if not skip_contigs:
-                yield rec['locus'], rec['contig']
+                if 'contig' in rec:
+                    yield rec['locus'], rec['contig']
+                elif 'WGS' in rec:
+                    yield rec['locus'], rec['WGS']
+                else:
+                    yield rec['locus'], None
             continue
         
         for feature in rec['features']:
