@@ -1,9 +1,10 @@
 #!/usr/bin/env python
+
 __author__ = "Jesse Zaneveld"
-__copyright__ = "Copyright 2007-2010, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Jesse Zaneveld", "Rob Knight"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Jesse Zaneveld"
 __email__ = "zaneveld@gmail.com"
 __status__ = "Release"
@@ -40,4 +41,4 @@ if __name__ == '__main__':
     from sys import argv
     filename = argv[1]
     for result_line in parse_pos_file(filename):
-        print result_line
+        print result_line.strip()
