@@ -7,12 +7,12 @@ Float = numpy.core.numerictypes.sctype2char(float)
 from cogent.evolve import substitution_model
 
 __author__ = "Matthew Wakefield"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Matthew Wakefield", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Matthew Wakefield"
-__email__ = "matthew.wakefield@anu.edu.au"
+__email__ = "wakefield@wehi.edu.au"
 __status__ = "Production"
 
 three_letter_order = 'ARNDCQEGHILKMFPSTWYV'
@@ -47,4 +47,4 @@ def PamlMatrixParser(f):
     
     freqs = dict(zip(three_letter_order, freqs))
     
-    return (matrix, freqs)
\ No newline at end of file
+    return (matrix, freqs)
