@@ -5,12 +5,12 @@ from cogent.core.tree import TreeBuilder
 from cogent import LoadTree
 
 __author__ = "Matthew Wakefield"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Matthew Wakefield", "Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Matthew Wakefield"
-__email__ = "matthew.wakefield@anu.edu.au"
+__email__ = "wakefield@wehi.edu.au"
 __status__ = "Production"
 
 
@@ -41,7 +41,7 @@ def weightedMajorityRule(weighted_trees, strict=False, attr="support"):
         for edge in edges:
             tips = edge.getTipNames(includeself=True)
             tips = frozenset(tips)
-            if not cladecounts.has_key(tips):
+            if tips not in cladecounts:
                 cladecounts[tips] = 0
             cladecounts[tips] += weight
             length = edge.Length and edge.Length * weight
