@@ -3,20 +3,20 @@ from __future__ import division, with_statement
 import numpy
 Float = numpy.core.numerictypes.sctype2char(float)
 import time, warnings
-from cogent.maths.optimisers import optimise
 from cogent.maths.solve import find_root
 from cogent.util import parallel
-from cogent.maths.optimiser import ParameterOutOfBoundsError
+from cogent.maths.optimisers import maximise, ParameterOutOfBoundsError
 
 
 import os
 TRACE_DEFAULT = os.environ.has_key('COGENT_TRACE')
+TRACE_SCALE = 100000
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -33,7 +33,7 @@ class OptPar(object):
     An OptPar reports changes to the ParameterValueSet for its parameter.
     """
     
-    is_const = False
+    is_constant = False
     recycled = False
     args = ()
     # Use of __slots__ here and in Cell gives 8% speedup on small calculators.
@@ -90,7 +90,7 @@ class LogOptPar(OptPar):
     
 
 class EvaluatedCell(object):
-    __slots__ = ['client_ranks', 'rank', 'calc', 'args', 'is_const',
+    __slots__ = ['client_ranks', 'rank', 'calc', 'args', 'is_constant',
         'clients', 'failure_count', 'name', 'arg_ranks',
         'consequences', 'recycled', 'default']
     
@@ -105,11 +105,11 @@ class EvaluatedCell(object):
         if recycling:
             self.args = (self,) + self.args
         
-        self.is_const = True
+        self.is_constant = True
         for arg in args:
             arg.addClient(self)
-            if not arg.is_const:
-                self.is_const = False
+            if not arg.is_constant:
+                self.is_constant = False
         
         self.clients = []
         self.client_ranks = []
@@ -123,7 +123,7 @@ class EvaluatedCell(object):
                 *[data[arg_rank] for arg_rank in self.arg_ranks])
     
     def prime(self, data_sets):
-        if self.is_const:
+        if self.is_constant:
             # Just calc once
             self.update(data_sets[0])
             for data in data_sets[1:]:
@@ -149,7 +149,7 @@ class ConstCell(object):
     __slots__ = ['name', 'scope', 'value', 'rank', 'consequences', 'clients']
     
     recycled = False
-    is_const = True
+    is_constant = True
     args = ()
     
     def __init__(self, name, value):
@@ -201,7 +201,7 @@ class Calculator(object):
                     self.arg_ranks[i].append(arg.rank)
                     cell.arg_ranks.append(arg.rank)
                 
-                with parallel.mpi_context(self.remaining_parallel_context):
+                with parallel.parallel_context(self.remaining_parallel_context):
                     try:
                         cell.prime(self.cell_values)
                     except KeyboardInterrupt:
@@ -265,8 +265,8 @@ class Calculator(object):
                     label = '[]'
                 label = '<%s> %s' % (cell.rank, label)
                 enodes.append(label)
-                all_const = all_const and cell.is_const
-                some_const = some_const or cell.is_const
+                all_const = all_const and cell.is_constant
+                some_const = some_const or cell.is_constant
             enodes = '|'.join(enodes)
             colour = ['', ' fillcolor=gray90, style=filled,'][some_const]
             colour = [colour, ' fillcolor=gray, style=filled,'][all_const]
@@ -305,19 +305,10 @@ class Calculator(object):
             time.sleep(5)
             os.remove(fn)
     
-    def optimise(self, local=None, filename=None, interval=None,
-            max_evaluations=None, tolerance=1e-6, global_tolerance=1e-1, **kw):
-        """Find input values that optimise this function.
-        'local' controls the choice of optimiser, the default being to run
-        both the global and local optimisers. 'filename' and 'interval'
-        control checkpointing.  Unknown keyword arguments get passed on to
-        the optimiser(s)."""
-        for n in ['local', 'filename', 'interval', 'max_evaluations', 
-                'tolerance', 'global_tolerance']:
-            kw[n] = locals()[n]
+    def optimise(self, **kw):
         x = self.getValueArray()
         bounds = self.getBoundsVectors()
-        optimise(self, x, bounds, **kw)
+        maximise(self, x, bounds, **kw)
         self.optimised = True
     
     def setTracing(self, trace=False):
@@ -328,14 +319,15 @@ class Calculator(object):
         if trace:
             print
             n_opars = len(self.opt_pars)
-            n_cells = len([c for c in self._cells if not c.is_const])
-            print n_opars, "OptPars and", n_cells - n_opars, "cells"
-            print self.opt_pars
-            
+            n_cells = len([c for c in self._cells if not c.is_constant])
+            print n_opars, "OptPars and", n_cells - n_opars, "derived values"
+            print 'OptPars: ', ', '.join([par.name for par in self.opt_pars])
+            print "Times in 1/%sths of a second" % TRACE_SCALE
+
             groups = []
             groupd = {}
             for cell in self._cells:
-                if cell.is_const or not isinstance(cell, EvaluatedCell):
+                if cell.is_constant or not isinstance(cell, EvaluatedCell):
                     continue
                 if cell.name not in groupd:
                     group = []
@@ -414,7 +406,8 @@ class Calculator(object):
         
         t0 = time.time()
         self.evaluations += 1
-        assert parallel.getCommunicator() is self.overall_parallel_context
+        assert parallel.getContext() is self.overall_parallel_context, (
+            parallel.getContext(), self.overall_parallel_context)
         
         # If ALL of the changes made in the last step are reversed in this step
         # then it is safe to undo them first, taking advantage of the 1-deep
@@ -461,7 +454,7 @@ class Calculator(object):
             else:
                 data[i] = v
         
-        with parallel.mpi_context(self.remaining_parallel_context):
+        with parallel.parallel_context(self.remaining_parallel_context):
             try:
                 if self.trace:
                     self.tracingUpdate(changes, program, data)
@@ -520,9 +513,8 @@ class Calculator(object):
     def tracingUpdate(self, changes, program, data):
         # Does the same thing as plainUpdate, but also produces lots of
         # output showing how long each step of the calculation takes.
-        # One line per call, '-' for undo, '+' for calculation, times
-        # in 10000ths of a second.
-        
+        # One line per call, '-' for undo, '+' for calculation
+                
         exception = None
         elapsed = {}
         for cell in program:
@@ -543,7 +535,7 @@ class Calculator(object):
                 edge_width = min(len(text), (width - 4 - 3)) // 2
                 elipsis = ['   ','...'][not not text.strip()]
                 text = text[:edge_width] + elipsis + text[-edge_width:]
-            tds.append('%s%4s' % (text, int((10000*(elap))) or ''))
+            tds.append('%s%4s' % (text, int(TRACE_SCALE*elap+0.5) or ''))
         
         par_descs = []
         for (i,v) in changes:
