@@ -7,12 +7,13 @@ from .setting import Var, ConstVal
 from .calculation import Calculator
 from cogent.util import parallel
 from cogent.maths.stats.distribution import chdtri
+from cogent.maths.optimisers import MaximumEvaluationsReached
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -465,8 +466,9 @@ class _LeafDefn(_Defn):
     name = None
     name_required = True
     
-    # This can be overriden in a subclass or the constuctor.
+    # These can be overriden in a subclass or the constuctor.
     valid_dimensions = ()
+    numeric = False
     
     array_template = None
     internal_dimensions = ()
@@ -497,19 +499,66 @@ class _LeafDefn(_Defn):
         gdv = lambda x:x.getDefaultValue()
         self.values = [nullor(self.name, gdv)(u) for u in self.uniq]
     
-    def assign(self, settings):
-        for (scope, setting) in settings:
+    def assignAll(self, scope_spec=None, value=None,
+            lower=None, upper=None, const=None, independent=None):
+        settings = []
+        if const is None:
+            const = self.const_by_default
+        
+        for scope in self.interpretScopes(
+                independent=independent, **(scope_spec or {})):
+            if value is None:
+                s_value = self.getMeanCurrentValue(scope)
+            else:       
+                s_value = self.unwrapValue(value)
+            
+            if const:
+                setting = ConstVal(s_value)
+            elif not self.numeric:
+                if lower is not None or upper is not None:
+                    raise ValueError(
+                            "Non-scalar input '%s' doesn't support bounds"
+                            % self.name)
+                setting = Var((None, s_value, None))
+            else:
+                (s_lower, s_upper) = self.getCurrentBounds(scope)
+                if lower is not None:
+                    s_lower = lower
+                if upper is not None:
+                    s_upper = upper
+                    
+                if s_lower > s_upper:
+                    raise ValueError("Bounds: upper < lower")
+                elif (s_lower is not None) and s_value < s_lower:
+                    s_value = s_lower
+                    warnings.warn("Value of %s increased to keep within bounds" 
+                                % self.name, stacklevel=3)
+                elif (s_upper is not None) and s_value > s_upper:
+                    s_value = s_upper
+                    warnings.warn("Value of %s decreased to keep within bounds" 
+                                % self.name, stacklevel=3)
+                setting = Var((s_lower, s_value, s_upper))
             self.checkSettingIsValid(setting)
+            settings.append((scope, setting))
+            
+        for (scope, setting) in settings:
             for scope_t in scope:
                 assert scope_t in self.assignments, scope_t
                 self.assignments[scope_t] = setting
     
-    #def getNumFreeParams(self):
-    #    return sum(setting.getNumFreeParams() for setting in self.uniq)
-    
-    def getAllDefaultValues(self, scope):
-        return [self.assignments[s].getDefaultValue() for s in scope]
-    
+    def getMeanCurrentValue(self, scope):
+        values = [self.assignments[s].getDefaultValue() for s in scope]
+        if len(values) == 1:
+            s_value = values[0]
+        else:
+            s_value = sum(values) / len(values)
+            for value in values:
+                if not numpy.all(value==s_value):
+                    warnings.warn("Used mean of %s %s values" % 
+                            (len(values), self.name), stacklevel=4)
+                    break
+        return s_value
+                    
     def getCurrentBounds(self, scope):
         lowest = highest = None
         for s in scope:
@@ -533,7 +582,7 @@ class _LeafDefn(_Defn):
         for (i,a) in self.assignments.items():
             if a is None:
                 assignments.append('None')
-            elif a.is_const:
+            elif a.is_constant:
                 if isinstance(a.value, float):
                     assignments.append(template % a.value)
                 else:
@@ -693,59 +742,27 @@ class ParameterController(object):
                     self._changed.add(id(c))
         self._changed.clear()
     
-    def assignAll(self, par_name, scope_spec=None, value=None,
-            lower=None, upper=None, const=None, independent=None):
-        settings = []
+    def assignAll(self, par_name, *args, **kw):
         defn = self.defn_for[par_name]
         if not isinstance(defn, _LeafDefn):
             args = ' and '.join(['"%s"' % a.name for a in defn.args])
             msg = '"%s" is not settable as it is derived from %s.' % (
                     par_name, args)
             raise ValueError(msg)
-        
-        if const is None:
-            const = defn.const_by_default
-        
-        for scope in defn.interpretScopes(
-                independent=independent, **(scope_spec or {})):
-            if value is None:
-                values = defn.getAllDefaultValues(scope)
-                if len(values) == 1:
-                    s_value = values[0]
-                else:
-                    s_value = sum(values) / len(values)
-                    for value in values:
-                        if not numpy.all(value==s_value):
-                            warnings.warn("Used mean of %s values" % par_name,
-                                    stacklevel=3)
-                            break
-            else:       
-                s_value = defn.unwrapValue(value)
-            if const:
-                setting = ConstVal(s_value)
-            else:
-                (s_lower, s_upper) = defn.getCurrentBounds(scope)
-                if lower is not None: s_lower = lower
-                if upper is not None: s_upper = upper
-                setting = Var((s_lower, s_value, s_upper))
-            settings.append((scope, setting))
-        defn.assign(settings)
+        defn.assignAll(*args, **kw)
         self.updateIntermediateValues([defn])
         
     def measureEvalsPerSecond(self, *args, **kw):
         return self.makeCalculator().measureEvalsPerSecond(*args, **kw)
     
     def setupParallelContext(self, parallel_split=None):
-        comm = parallel.getCommunicator()
-        cpu_count = comm.Get_size()
-        if parallel_split is None:
-            parallel_split = cpu_count
-        with parallel.mpi_split(parallel_split) as parallel_context:
-            self.remaining_parallel_context = parallel.getCommunicator()
+        self.overall_parallel_context = parallel.getContext()
+        with parallel.split(parallel_split) as parallel_context:
+            parallel_context = parallel_context.getCommunicator()
+            self.remaining_parallel_context = parallel.getContext()
             if 'parallel_context' in self.defn_for:
                 self.assignAll(
                     'parallel_context', value=parallel_context, const=True)
-            self.overall_parallel_context = comm
     
     def makeCalculator(self, calculatorClass=None, variable=None, **kw):
         cells = []
@@ -772,11 +789,33 @@ class ParameterController(object):
     def getNumFreeParams(self):
         return sum(defn.getNumFreeParams() for defn in self.defns if isinstance(defn, _LeafDefn))
 
-    def optimise(self, *args, **kw):
-        return_calculator = kw.pop('return_calculator', False)
+    def optimise(self, local=None, 
+            filename=None, interval=None,
+            limit_action='warn',  max_evaluations=None, 
+            tolerance=1e-6, global_tolerance=1e-1, **kw):
+        """Find input values that optimise this function.
+        'local' controls the choice of optimiser, the default being to run
+        both the global and local optimisers. 'filename' and 'interval'
+        control checkpointing.  Unknown keyword arguments get passed on to
+        the optimiser(s)."""
+        return_calculator = kw.pop('return_calculator', False) # only for debug
+        for n in ['local', 'filename', 'interval', 'max_evaluations', 
+                'tolerance', 'global_tolerance']:
+            kw[n] = locals()[n]
         lc = self.makeCalculator()
-        lc.optimise(*args, **kw)
-        self.updateFromCalculator(lc)
+        try:
+            lc.optimise(**kw)
+        except MaximumEvaluationsReached, detail:
+            evals = detail[0]
+            err_msg = 'FORCED EXIT from optimiser after %s evaluations' % evals
+            if limit_action == 'ignore':
+                pass
+            elif limit_action == 'warn':
+                warnings.warn(err_msg, stacklevel=2)
+            else:
+                raise ArithmeticError(err_msg)    
+        finally:
+            self.updateFromCalculator(lc)
         if return_calculator:
             return lc
     
