@@ -3,10 +3,10 @@
 by a parameter controller"""
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Peter Maxwell"
 __email__ = "pm67nz@gmail.com"
 __status__ = "Production"
@@ -16,7 +16,7 @@ class Setting(object):
 
 class Var(Setting):
     # placeholder for a single optimiser parameter
-    is_const = False
+    is_constant = False
     
     def __init__(self, bounds = None):
         if bounds is None:
@@ -49,7 +49,7 @@ class ConstVal(Setting):
     # not to be confused with defns.Const.  This is like a Var,
     # assigned to a parameter which may have other Var values
     # for other scopes.
-    is_const = True
+    is_constant = True
     
     # Val interface
     def __init__(self, value):
