@@ -9,16 +9,18 @@ Table can read pickled and delimited formats.
 """
 from __future__ import division
 import cPickle, csv
+from gzip import GzipFile
+
 import numpy
 from cogent.format import table as table_format
 
 from cogent.util.dict_array import DictArray
 
 __author__ = "Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "Felix Schill"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -307,7 +309,7 @@ class Table(DictArray):
                                       compact=compact)
     
     def writeToFile(self, filename, mode = 'w', writer = None, format = None,
-                 sep = None, **kwargs):
+                 sep = None, compress=None, **kwargs):
         """Write table to filename in the specified format. If a format is not
         specified, it attempts to use a filename suffix. Note if a sep argument
         is provided, unformatted values are written to file in order to preserve
@@ -319,14 +321,28 @@ class Table(DictArray):
               pickle.
             - writer: a function for formatting the data for output.
             - sep: a character delimiter for fields.
+            - compress: if True, gzips the file and appends .gz to the
+              filename (if not already added).
         """
+        compress = compress or filename.endswith('.gz')
+        
+        if compress:
+            if not filename.endswith('.gz'):
+                filename = '%s.gz' % filename
+            mode = ['wb', mode][mode == 'w']
+            outfile = GzipFile(filename, mode)
+        else:
+            outfile = file(filename, mode)
         
-        outfile = file(filename, mode)
         if format is None:
             # try guessing from filename suffix
+            if compress:
+                index = -2
+            else:
+                index = -1
             suffix = filename.split('.')
             if len(suffix) > 1:
-                format = suffix[-1]
+                format = suffix[index]
         
         if writer:
             rows = self.getRawData()
@@ -864,7 +880,8 @@ class Table(DictArray):
         
         raw_data = self.getRawData()
         raw_data.insert(0, self.Header)
-        transposed = numpy.transpose(raw_data)
+        transposed = numpy.array(raw_data, dtype='O')
+        transposed = transposed.transpose()
         
         # indices for the header and non header rows
         header_index = self.Header.index(select_as_header)
