@@ -7,12 +7,12 @@ import doctest, cogent.util.unit_test as unittest, sys, os
 from cogent.util.misc import app_path
 
 __author__ = "Peter Maxwell and Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Rob Knight",
                     "Hau Ying", "Helen Lindsay", "Jeremy Widmann",
                     "Sandra Smit", "Greg Caporaso", "Matthew Wakefield"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -86,11 +86,13 @@ def suite():
         'test_evolve.test_scale_rules',
         'test_evolve.test_likelihood_function',
         'test_evolve.test_newq',
+        'test_evolve.test_pairwise_distance',
         'test_evolve.test_parameter_controller',
         'test_format.test_mage',
         'test_format.test_fasta',
         'test_format.test_pdb_color',
         'test_format.test_xyzrn',
+        'test_maths.test_fit_function',
         'test_maths.test_geometry',
         'test_maths.test_matrix_logarithm',
         'test_maths.test_period',
@@ -118,6 +120,7 @@ def suite():
         'test_parse.test_agilent_microarray',
         'test_parse.test_binary_sff',
         'test_parse.test_blast',
+        'test_parse.test_bowtie',
         'test_parse.test_bpseq',
         'test_parse.test_cigar',
         'test_parse.test_clustal',
@@ -132,9 +135,11 @@ def suite():
         'test_parse.test_ebi',
         'test_parse.test_fasta',
         'test_parse.test_fastq',
+        'test_parse.test_gbseq',
         'test_parse.test_gibbs',
         'test_parse.test_genbank',
         'test_parse.test_gff',
+        'test_parse.test_greengenes',
         'test_parse.test_ilm',
         'test_parse.test_illumina_sequence',
         'test_parse.test_locuslink',
@@ -145,7 +150,9 @@ def suite():
         'test_parse.test_nexus',
         'test_parse.test_nupack',
         'test_parse.test_pdb',
+        'test_parse.test_psl',
         'test_parse.test_structure',
+        'test_parse.test_pamlmatrix',
         'test_parse.test_phylip',
         'test_parse.test_pknotsrg',
         'test_parse.test_rdb',
@@ -157,6 +164,7 @@ def suite():
         'test_parse.test_rnaview',
         'test_parse.test_rnaforester',
         'test_parse.test_sprinzl',
+        'test_parse.test_tinyseq',
         'test_parse.test_tree',
         'test_parse.test_unigene',
         'test_seqsim.test_analysis',
@@ -192,11 +200,7 @@ def suite():
     except:
         print >> sys.stderr, "No matplotlib so not running test_draw.py"
     else:
-        print >> sys.stderr, \
-          "NOTE: test_draw.py must be run separately"
-        # matplotlib.use('Agg') # non interactive
-        # test_draw not yet structured as unit tests
-        #modules_to_test.append('test_draw')
+        modules_to_test.append('test_draw')
 
     #Try importing modules for app controllers
     apps = [('blastall', 'test_blast'),
@@ -236,15 +240,19 @@ def suite():
             ('uclust','test_uclust')
             ]
     for app, test_name in apps:
+        should_run_test = False
         if app_path(app):
-            modules_to_test.append('test_app.' + test_name)
-        elif app == 'rdp_classifier-2.0.jar' and os.environ.get('RDP_JAR_PATH'):
+            should_run_test = True
+        elif app.startswith('rdp_classifier') and os.environ.get('RDP_JAR_PATH'):
             # This is ugly, but because this is a jar file, it won't be in 
             # $PATH -- we require users to set an environment variable to 
             # point to the location of this jar file, so we test for that. 
             # My new version of app_path can be applied to do smarter checks,
             # but will involve some re-write of how we check whether tests can
             # be run. -Greg
+            if app == os.path.basename('RDP_JAR_PATH'):
+                should_run_test = True
+        if should_run_test:
             modules_to_test.append('test_app.' + test_name)
         else:
             print >> sys.stderr, "Can't find %s executable: skipping test" % app
@@ -275,8 +283,9 @@ def suite():
                      'test_db.test_ensembl.test_compara',
                      'test_db.test_ensembl.test_genome',
                      'test_db.test_ensembl.test_host',
+                     'test_db.test_ensembl.test_metazoa',
                      'test_db.test_ensembl.test_species',
-                      'test_db.test_ensembl.test_feature_level']
+                     'test_db.test_ensembl.test_feature_level']
         else:
             print >> sys.stderr, "Environment variable ENSEMBL_ACCOUNT not "\
             "set: skipping db.ensembl tests"
@@ -286,11 +295,11 @@ def suite():
     else:
         print >> sys.stderr, \
                 "Environment variable TEST_DB=1 not set: skipping db tests"
-
-    assert sys.version_info >= (2, 4)
-
+    
+    assert sys.version_info >= (2, 6)
+    
     alltests = unittest.TestSuite()
-
+    
     for module in modules_to_test:
         if module.endswith('.rst'):
             module = os.path.join(*module.split(".")[:-1]) + ".rst"
@@ -309,6 +318,12 @@ class BoobyTrappedStream(object):
     def write(self, text):
         self.output.write(text)
         raise RuntimeError, "Output not allowed in tests"
+        
+    def flush(self):
+        pass
+        
+    def isatty(self):
+        return False
 
 if __name__ == '__main__':
     if '--debug' in sys.argv:
