@@ -13,10 +13,10 @@ import cogent.align.progressive
 import unittest
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Rob Knight"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -90,6 +90,17 @@ class AlignmentTestCase(unittest.TestCase):
         self.assertEqual(matchedColumns(a), 6)
         self.assertEqual(len(a), 9)
     
+    def test_local_tiebreak(self):
+        """Should pick the first best-equal hit rather than the last one"""
+        # so that the Pyrex and Python versions give the same result.
+        score_matrix = make_dna_scoring_dict(match=1, transition=-1, 
+                transversion=-1)
+        pattern = DNA.makeSequence('cwc', Name='pattern')
+        two_hit = DNA.makeSequence( 'cactc', Name= 'target')
+        aln = local_pairwise(pattern, two_hit, score_matrix, 5, 2)
+        hit = aln.NamedSeqs['target']
+        self.assertEqual(str(hit).lower(), 'cac')
+
 
 class UnalignedPairTestCase(unittest.TestCase):
     def test_forward(self):
