@@ -11,12 +11,12 @@ from cogent.util.unit_test import TestCase, main
 from numpy import array, arange
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Rob Knight", "Catherine Lozupone", "Daniel McDonald",
                "Peter Maxwell", "Gavin Huttley", "Andrew Butterfield",
                "Matthew Wakefield", "Justin Kuczynski","Jens Reeder"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
@@ -832,7 +832,31 @@ class TreeNodeTests(TestCase):
         self.assertEqual(len(parent), 2)
         self.assertEqual(parent.removeNode(children[0]), True)
         self.assertEqual(len(parent), 1)
-    
+   
+    def test_lowestCommonAncestor(self):
+        """TreeNode lowestCommonAncestor should return LCA for set of tips"""
+        t1 = DndParser("((a,(b,c)d)e,f,(g,h)i)j;")
+        t2 = t1.copy()
+        t3 = t1.copy()
+        t4 = t1.copy()
+        input1 = ['a'] # return self
+        input2 = ['a','b'] # return e
+        input3 = ['b','c'] # return d
+        input4 = ['a','h','g'] # return j
+        exp1 = t1.getNodeMatchingName('a')
+        exp2 = t2.getNodeMatchingName('e')
+        exp3 = t3.getNodeMatchingName('d')
+        exp4 = t4
+        obs1 = t1.lowestCommonAncestor(input1)
+        obs2 = t2.lowestCommonAncestor(input2)
+        obs3 = t3.lowestCommonAncestor(input3)
+        obs4 = t4.lowestCommonAncestor(input4)
+        self.assertEqual(obs1, exp1)
+        self.assertEqual(obs2, exp2)
+        self.assertEqual(obs3, exp3)
+        self.assertEqual(obs4, exp4)
+
+
     def test_lastCommonAncestor(self):
         """TreeNode LastCommonAncestor should provide last common ancestor"""
         nodes, tree = self.TreeNode, self.TreeRoot
@@ -1256,6 +1280,22 @@ class PhyloNodeTests(TestCase):
         c.Length = None   #need to test both leaf and internal node
         self.assertEqual(str(a), '(((d:1,e:4,(g:3)f:2)c)b:0,h)a;')
 
+    def test_getMaxTipTipDistance(self):
+        """getMaxTipTipDistance should get max tip distance across tree"""
+        nodes, tree = self.TreeNode, self.TreeRoot
+        dist, names, node = tree.getMaxTipTipDistance()
+        self.assertEqual(dist, 15.0) # due to nodes with single descendents!!
+        self.assertEqual(sorted(names), ['e','g'])
+        self.assertEqual(node.Name, 'b')
+
+    def test_setMaxTipTipDistance(self):
+        """setMaxTipTipDistance sets MaxDistTips across tree"""
+        nodes, tree = self.TreeNode, self.TreeRoot
+        tree.setMaxTipTipDistance()
+        tip_a, tip_b = tree.MaxDistTips
+        self.assertEqual(tip_a[0] + tip_b[0], 10)
+        self.assertEqual(sorted([tip_a[1],tip_b[1]]), ['g','h'])
+
     def test_maxTipTipDistance(self):
         """maxTipTipDistance returns the max dist between any pair of tips"""
         nodes, tree = self.TreeNode, self.TreeRoot
@@ -1707,6 +1747,124 @@ class TestTree(TestCase):
         self.assertEqual(*[len(t.Children) for t in (subtree,new_tree)])
         self.assertEqual(str(subtree), str(new_tree))
     
+    def test_getsubtree_2(self):
+        """tree.getSubTree() has same pairwise tip dists as tree (len0 node)
+        """
+        t1 = DndParser('((a:1,b:2):4,((c:3, j:17.2):0,(d:1,e:1):2):3)', \
+            PhyloNode) # note c,j is len 0 node
+        orig_dists = t1.getDistances()
+        subtree = t1.getSubTree(set(['a','b','d','e','c']))
+        sub_dists = subtree.getDistances()
+        for pair, dist in sub_dists.items():
+            self.assertEqual((pair,dist), (pair,orig_dists[pair]))
+
+    def test_getsubtree_3(self):
+        """tree.getSubTree() has same pairwise tip dists as tree 
+
+        (nonzero nodes)
+        """
+        t1 = DndParser('((a:1,b:2):4,((c:3, j:17):0,(d:1,e:1):2):3)', \
+            PhyloNode) # note c,j is len 0 node
+        orig_dists = t1.getDistances()
+        subtree = t1.getSubTree(set(['a','b','d','e','c']))
+        sub_dists = subtree.getDistances()
+        # for pair, dist in sub_dists.items():
+            # self.assertEqual((pair,dist), (pair,orig_dists[pair]))
+        t2 = DndParser('((a:1,b:2):4,((c:2, j:16):1,(d:1,e:1):2):3)', \
+            PhyloNode) # note c,j similar to above
+        t2_dists = t2.getDistances()
+        # ensure t2 is same as t1, except j->c or c->j
+        for pair, dist in t2_dists.items():
+            if (pair == ('c','j')) or (pair == ('j','c')):
+                continue
+            self.assertEqual((pair,dist), (pair,orig_dists[pair]))
+        sub2 = t2.getSubTree(set(['a','b','d','e','c']))
+        sub2_dists = sub2.getDistances()
+        for pair, dist in sub2_dists.items():
+            self.assertEqual((pair,dist), (pair,orig_dists[pair]))        
+
+    def test_getsubtree_4(self):
+        """tree.getSubTree() handles keep_root correctly
+        """
+        t1 = DndParser('((a:1,b:2):4,(((c:2)cparent:1, j:17):0,(d:1,e:4):2):3)')
+        #           /----4--- /--1-a
+        # ---------|          \--2-b
+        #          |          /----0--- /-1---cparent---2---c
+        #           \---3----|          \--17-j
+        #                     \----2--- /--1--d
+        #                               \--4--e
+        # note c,j is len 0 node
+
+        true_dists = {('a', 'b'): 3.0,
+         ('a', 'c'): 11.0,
+         ('a', 'd'): 11.0,
+         ('a', 'e'): 14.0,
+         ('a', 'j'): 25.0,
+         ('b', 'a'): 3.0,
+         ('b', 'c'): 12.0,
+         ('b', 'd'): 12.0,
+         ('b', 'e'): 15.0,
+         ('b', 'j'): 26.0,
+         ('c', 'a'): 11.0,
+         ('c', 'b'): 12.0,
+         ('c', 'd'): 6.0,
+         ('c', 'e'): 9.0,
+         ('c', 'j'): 20.0,
+         ('d', 'a'): 11.0,
+         ('d', 'b'): 12.0,
+         ('d', 'c'): 6.0,
+         ('d', 'e'): 5.0,
+         ('d', 'j'): 20.0,
+         ('e', 'a'): 14.0,
+         ('e', 'b'): 15.0,
+         ('e', 'c'): 9.0,
+         ('e', 'd'): 5.0,
+         ('e', 'j'): 23.0,
+         ('j', 'a'): 25.0,
+         ('j', 'b'): 26.0,
+         ('j', 'c'): 20.0,
+         ('j', 'd'): 20.0,
+         ('j', 'e'): 23.0}
+
+        true_root_dists = {'a':5,'b':6,'c':6,'j':20,'d':6,'e':9}
+
+        t1_dists = t1.getDistances() # 
+        subtree = t1.getSubTree(set(['d','e','c']))
+        sub_dists = subtree.getDistances()
+        true_sub_root_dists = {'c':3,'d':3,'e':6}
+
+        sub_sameroot = t1.getSubTree(set(['d','e','c']), keep_root=True)
+        sub_sameroot_dists = sub_sameroot.getDistances()
+
+        sub_sameroot2 = t1.getSubTree(set(['j','c']), keep_root=True)
+        sub_sameroot_dists2 = sub_sameroot2.getDistances()
+
+        # tip to tip dists should be the same
+        for tip_pair in sub_dists.keys():
+            self.assertEqual(sub_dists[tip_pair],true_dists[tip_pair])
+        for tip_pair in t1_dists.keys():
+            self.assertEqual(t1_dists[tip_pair],true_dists[tip_pair])
+        for tip_pair in sub_sameroot_dists.keys():
+            self.assertEqual(sub_sameroot_dists[tip_pair],
+                true_dists[tip_pair])
+        for tip_pair in sub_sameroot_dists2.keys():
+            self.assertEqual(sub_sameroot_dists2[tip_pair],
+                true_dists[tip_pair])
+
+        # sameroot should have longer root to tip dists
+        for tip in t1.tips():
+            self.assertFloatEqual(t1.distance(tip),
+                true_root_dists[tip.Name])
+        for tip in subtree.tips():
+            self.assertFloatEqual(subtree.distance(tip),
+                true_sub_root_dists[tip.Name])
+        for tip in sub_sameroot.tips():
+            self.assertFloatEqual(sub_sameroot.distance(tip),
+                true_root_dists[tip.Name])
+        for tip in sub_sameroot2.tips():
+            self.assertFloatEqual(sub_sameroot2.distance(tip),
+                true_root_dists[tip.Name])
+
     def test_ascii(self):
         self.tree.asciiArt()
         # unlabeled internal node
