@@ -7,19 +7,19 @@ from cogent.db.ensembl.assembly import Coordinate, CoordSystem, \
 from cogent.db.ensembl.genome import Genome
 
 __author__ = "Gavin Huttley, Hua Ying"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "hua Ying"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
 
-Release = 58
+Release = 62
 
 if 'ENSEMBL_ACCOUNT' in os.environ:
-    username, password = os.environ['ENSEMBL_ACCOUNT'].split()
-    account = HostAccount('127.0.0.1', username, password)
+    host, username, password = os.environ['ENSEMBL_ACCOUNT'].split()
+    account = HostAccount(host, username, password)
 else:
     account = get_ensembl_account(release=Release)
 
