@@ -5,19 +5,19 @@ from cogent.db.ensembl.host import HostAccount, get_ensembl_account
 from cogent.db.ensembl.database import Database
 
 __author__ = "Gavin Huttley, Hua Ying"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "hua Ying"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
 
-Release = 58
+Release = 62
 
 if 'ENSEMBL_ACCOUNT' in os.environ:
-    username, password = os.environ['ENSEMBL_ACCOUNT'].split()
-    account = HostAccount('127.0.0.1', username, password)
+    host, username, password = os.environ['ENSEMBL_ACCOUNT'].split()
+    account = HostAccount(host, username, password)
 else:
     account = get_ensembl_account(release=Release)
 
@@ -33,10 +33,10 @@ class TestDatabase(TestCase):
         db = Database(account=account, release=Release,
                     species='human', db_type='variation')
         tn, tc = 'variation_feature', 'consequence_type'
-        expected = set((('3PRIME_UTR', 'ESSENTIAL_SPLICE_SITE'),
-                    ('3PRIME_UTR', 'SPLICE_SITE'),
-                    ('5PRIME_UTR', 'ESSENTIAL_SPLICE_SITE')))
-        self.assertNotEquals(set(db.getDistinct(tn, tc)) & expected, set())
+        expected = set(('3_prime_UTR_variant', 'splice_acceptor_variant',
+                        '5_prime_UTR_variant'))
+        got = db.getDistinct(tn, tc)
+        self.assertNotEquals(set(got) & expected, set())
         
         db = Database(account=account, release=Release,
                     species='human', db_type='core')
@@ -45,7 +45,7 @@ class TestDatabase(TestCase):
           'Mt_tRNA', 'Mt_rRNA', 'IG_V_gene', 'IG_J_gene',
           'IG_C_gene', 'IG_D_gene', 'miRNA', 'misc_RNA', 'snoRNA', 'snRNA', 'rRNA'])
         got = set(db.getDistinct(tn, tc))
-        self.assertEquals(len(got&expected), len(expected))
+        self.assertNotEquals(set(got) & expected, set())
         
         db = Database(account=account, release=Release, db_type='compara')
         got = set(db.getDistinct('homology', 'description'))
@@ -55,16 +55,35 @@ class TestDatabase(TestCase):
     
     def test_get_table_row_counts(self):
         """should return correct row counts for some tables"""
-        expect = {'homo_sapiens_core_58_37c.analysis': 61L,
-                  'homo_sapiens_core_58_37c.seq_region': 55616L,
-                  'homo_sapiens_core_58_37c.assembly': 102090L,
-                  'homo_sapiens_core_58_37c.qtl': 0L}
+        expect = {'homo_sapiens_core_62_37g.analysis': 61L,
+                  'homo_sapiens_core_62_37g.seq_region': 55616L,
+                  'homo_sapiens_core_62_37g.assembly': 102090L,
+                  'homo_sapiens_core_62_37g.qtl': 0L}
         human = Database(account=account, release=Release,
                     species='human', db_type='core')
         table_names = [n.split('.')[1] for n in expect]
         got = dict(human.getTablesRowCount(table_names).getRawData())
-        self.assertEquals(got, expect)
+        for dbname in expect:
+            self.assertTrue(got[dbname] >= expect[dbname])
     
+    def test_table_has_column(self):
+        """return correct values for whether a Table has a column"""
+        account = get_ensembl_account(release=Release)
+        var61 = Database(account=account, release=61, species='human',
+            db_type='variation')
+        
+        var62 = Database(account=account, release=62, species='human',
+            db_type='variation')
+        
+        self.assertTrue(var61.tableHasColumn('transcript_variation',
+            'peptide_allele_string'))
+        self.assertFalse(var61.tableHasColumn('transcript_variation',
+            'pep_allele_string'))
+        
+        self.assertTrue(var62.tableHasColumn('transcript_variation',
+            'pep_allele_string'))
+        self.assertFalse(var62.tableHasColumn('transcript_variation',
+            'peptide_allele_string'))
 
 if __name__ == "__main__":
     main()
