@@ -2,10 +2,10 @@ from cogent.util.unit_test import TestCase, main
 from cogent.db.ensembl.species import Species
 
 __author__ = "Gavin Huttley, Hua Ying"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Gavin Huttley", "hua Ying"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "Gavin.Huttley@anu.edu.au"
 __status__ = "alpha"
@@ -54,8 +54,18 @@ class TestSpeciesNamemaps(TestCase):
         self.assertEqual(Species.getSpeciesName(ensembl_pref), species_name)
         self.assertEqual(Species.getCommonName(species_name), common_name2)
         self.assertEqual(Species.getCommonName(ensembl_pref), common_name2)
-        self.assertEqual(Species.getEnsemblDbPrefix(species_name),ensembl_pref)
-        self.assertEqual(Species.getEnsemblDbPrefix(common_name2),ensembl_pref)
+        self.assertEqual(Species.getEnsemblDbPrefix(species_name),
+            ensembl_pref)
+        self.assertEqual(Species.getEnsemblDbPrefix(common_name2),
+            ensembl_pref)
+    
+    def test_get_compara_name(self):
+        """should correctly form valid names for assignment onto objects"""
+        self.assertEqual(Species.getComparaName('pika'), 'Pika')
+        self.assertEqual(Species.getComparaName('C.elegans'), 'Celegans')
+        self.assertEqual(Species.getComparaName('Caenorhabditis elegans'),
+                'Celegans')
+    
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
