@@ -4,10 +4,10 @@ from cogent.util.unit_test import TestCase, main
 from cogent.db.rfam import Rfam
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
-__credits__ = ["Rob Knight"]
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
+__credits__ = ["Rob Knight","Jeremy Widmann"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
@@ -18,8 +18,8 @@ class RfamTests(TestCase):
         """Simple access of an item should work."""
         rec = Rfam()
         result = rec['rf00100'].read()
-        assert result.startswith('<pre>\n# STOCKHOLM')
-        assert 'M63671.1/163-492' in result
+        assert result.startswith('# STOCKHOLM')
+        assert 'AM773434.1/1-304' in result
 
 if __name__ == '__main__':
     main()
