@@ -14,6 +14,7 @@ import warnings
 
 warnings.filterwarnings("ignore", "Motif probs overspecified")
 warnings.filterwarnings("ignore", "Model not reversible")
+warnings.filterwarnings("ignore", "Ignoring tree edge lengths")
 
 import os
 from numpy import ones, dot
@@ -29,11 +30,11 @@ Nucleotide = substitution_model.Nucleotide
 MotifChange = predicate.MotifChange
 
 __author__ = "Peter Maxwell and Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Rob Knight",
                     "Matthew Wakefield", "Brett Easton"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -116,9 +117,9 @@ class LikelihoodCalcs(TestCase):
             alignment = alignment.getTranslation()
         calc = submod.makeLikelihoodFunction(self.tree, **kw)
         calc.setAlignment(alignment)
-        calc.setParamRule('length', value=1.0, is_const=True)
+        calc.setParamRule('length', value=1.0, is_constant=True)
         if not translate:
-            calc.setParamRule('kappa', value=3.0, is_const=True)
+            calc.setParamRule('kappa', value=3.0, is_constant=True)
         return calc
     
     def test_no_seq_named_root(self):
@@ -191,8 +192,8 @@ class LikelihoodCalcs(TestCase):
             mprob_model='tuple')
         lf = self._makeLikelihoodFunction(submod, 
                     bins=['slow', 'fast'])
-        lf.setParamRule('kappa', value=1.0, is_const=True)
-        lf.setParamRule('kappa', edge="Human", init=1.0, is_const=False)
+        lf.setParamRule('kappa', value=1.0, is_constant=True)
+        lf.setParamRule('kappa', edge="Human", init=1.0, is_constant=False)
         values = lf.getParamValueDict(['bin'])['kappa_factor'].values()
         self.assertEqual(round(sum(values) / len(values), 6), 1.0)
         self.assertEqual(len(values), 2)
@@ -207,7 +208,7 @@ class LikelihoodCalcs(TestCase):
             mprob_model='tuple')
         
         likelihood_function = self._makeLikelihoodFunction(submod)
-        likelihood_function.setParamRule('omega', value=0.5, is_const=True)
+        likelihood_function.setParamRule('omega', value=0.5, is_constant=True)
         evolve_lnL = likelihood_function.getLogLikelihood()
         self.assertFloatEqual(evolve_lnL, -80.67069614541883)
     
@@ -293,15 +294,15 @@ class LikelihoodFunctionTests(TestCase):
                 ("HowlerMon", 0.4),
                 ("Mouse",  0.5)]:
             likelihood_function.setParamRule("length", value=length, 
-                    edge=species, is_const=True)
+                    edge=species, is_constant=True)
         for (species1, species2, length) in [
                 ("Human", "HowlerMon", 0.7),
                 ("Human", "Mouse", 0.6)]:
             LCA = self.tree.getConnectingNode(species1, species2).Name
             likelihood_function.setParamRule("length", value=length, 
-                    edge=LCA, is_const=True)
+                    edge=LCA, is_constant=True)
         
-        likelihood_function.setParamRule("beta", value=4.0, is_const=True)
+        likelihood_function.setParamRule("beta", value=4.0, is_constant=True)
     
     def test_information_criteria(self):
         """test get information criteria from a model."""
@@ -478,8 +479,8 @@ motif  mprobs
     
     def test_set_par_all(self):
         likelihood_function = self._makeLikelihoodFunction()
-        likelihood_function.setParamRule("length", value=4.0, is_const=True)
-        likelihood_function.setParamRule("beta", value=6.0, is_const=True)
+        likelihood_function.setParamRule("length", value=4.0, is_constant=True)
+        likelihood_function.setParamRule("beta", value=6.0, is_constant=True)
         self.assertEqual(str(likelihood_function), \
 """Likelihood Function Table
 ======
@@ -548,7 +549,7 @@ motif    mprobs
     
     def test_getAnnotatedTree(self):
         likelihood_function = self._makeLikelihoodFunction()
-        likelihood_function.setParamRule("length", value=4.0, edge="Human", is_const=True)
+        likelihood_function.setParamRule("length", value=4.0, edge="Human", is_constant=True)
         result = likelihood_function.getAnnotatedTree()
         self.assertEqual(result.getNodeMatchingName('Human').params['length'], 4.0)
         self.assertEqual(result.getNodeMatchingName('Human').Length, 4.0)
@@ -597,11 +598,30 @@ motif    mprobs
         # checks by just trying to make the calculator
         lf = self.submodel.makeLikelihoodFunction(self.tree)
         lf.setAlignment(self.data)
-        lf.setParamRule('beta', is_const=True, value=2.0, 
+        lf.setParamRule('beta', is_constant=True, value=2.0, 
                         edges=['NineBande', 'DogFaced'], is_clade=True)
-        lf.setParamRule('beta', init=2.0, is_const=False,
+        lf.setParamRule('beta', init=2.0, is_constant=False,
                         edges=['NineBande', 'DogFaced'], is_clade=True)
     
+    def test_get_psub_rate_matrix(self):
+        """lf should return consistent rate matrix and psub"""
+        lf = self.submodel.makeLikelihoodFunction(self.tree)
+        lf.setAlignment(self.data)
+        Q = lf.getRateMatrixForEdge('NineBande')
+        P = lf.getPsubForEdge('NineBande')
+        self.assertFloatEqual(expm(Q.array)(1.0), P.array)
+        
+        # should fail for a discrete Markov model
+        dm = substitution_model.DiscreteSubstitutionModel(DNA.Alphabet)
+        lf = dm.makeLikelihoodFunction(self.tree)
+        lf.setAlignment(self.data)
+        self.assertRaises(Exception, lf.getRateMatrixForEdge, 'NineBande')
+    
+    def test_make_discrete_markov(self):
+        """lf ignores tree lengths if a discrete Markov model"""
+        t = LoadTree(treestring='(a:0.4,b:0.3,(c:0.15,d:0.2)edge.0:0.1)root;')
+        dm = substitution_model.DiscreteSubstitutionModel(DNA.Alphabet)
+        lf = dm.makeLikelihoodFunction(t)
 
 if __name__ == '__main__':
     main()
