@@ -1,18 +1,21 @@
 #! /usr/bin/env python
 # Matthew Wakefield Feb 2004
 
+from __future__ import with_statement
 import unittest
 import os
+import sys
+import warnings
 
 from cogent import LoadSeqs, LoadTree
 import cogent.evolve.parameter_controller, cogent.evolve.substitution_model
 from cogent.maths import optimisers
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Matthew Wakefield"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -76,7 +79,7 @@ class test_parameter_controller(unittest.TestCase):
         lf.setMotifProbs(mprobs)
         self.assertEqual(lf.getMotifProbs(), mprobs)
         
-        lf.setMotifProbsFromData(self.al[:1], is_const=True)
+        lf.setMotifProbsFromData(self.al[:1], is_constant=True)
         self.assertEqual(lf.getMotifProbs()['G'], 0.6)
         
         lf.setMotifProbsFromData(self.al[:1], pseudocount=1)
@@ -85,7 +88,7 @@ class test_parameter_controller(unittest.TestCase):
         # test with consideration of ambiguous states
         al = LoadSeqs(data = {'seq1': 'ACGTAAGNA', 'seq2': 'ACGTANGTC',
                                'seq3': 'ACGTACGTG'})
-        lf.setMotifProbsFromData(al, include_ambiguity=True, is_const=True)
+        lf.setMotifProbsFromData(al, include_ambiguity=True, is_constant=True)
         motif_probs = dict(lf.getMotifProbs())
         correct_probs = {'A': 8.5/27, 'C': 5.5/27, '-': 0.0, 'T': 5.5/27,
                          'G': 7.5/27}
@@ -101,8 +104,8 @@ class test_parameter_controller(unittest.TestCase):
         mprobs_a = dict(A=.2, T=.2, C=.3, G=.3)
         mprobs_b = dict(A=.1, T=.2, C=.3, G=.4)
         
-        for is_const in [False, True]:
-            lf.setMotifProbs(mprobs_a, is_const=is_const)
+        for is_constant in [False, True]:
+            lf.setMotifProbs(mprobs_a, is_constant=is_constant)
             s = str(lf)
             lf.setMotifProbs(mprobs_b, locus="b")
             self.assertEqual(lf.getMotifProbs(locus="a"), mprobs_a)
@@ -129,7 +132,7 @@ class test_parameter_controller(unittest.TestCase):
     def test_setConstantLengths(self):
         t = LoadTree(treestring='((a:1,b:2):3,(c:4,d:5):6,e:7);')
         lf = self.model.makeLikelihoodFunction(t)#self.tree)
-        lf.setParamRule('length', is_const=True)
+        lf.setParamRule('length', is_constant=True)
         # lf.setConstantLengths(t)
         lf.setAlignment(self.al)
         self.assertEqual(lf.getParamValue('length', 'b'), 2)
@@ -182,6 +185,20 @@ class test_parameter_controller(unittest.TestCase):
         self.assertEqual(rd['kappa']['b'],rd['kappa']['d'])
         self.assertNotEqual(rd['kappa']['a'],rd['kappa']['b'])
         
+    def test_bounds(self):
+        """Test setting upper and lower bounds for parameters"""
+        lf = self.model.makeLikelihoodFunction(self.tree)
+        lf.setParamRule('length', value=1, lower=0, upper=2)
+        
+        if sys.version_info >= (2, 6):
+            with warnings.catch_warnings(record=True) as w:
+                lf.setParamRule('length', value=3, lower=0, upper=2)
+                self.assertTrue(len(w), 'No warning issued')
+            self.assertEqual(lf.getParamValue('length', edge='a'), 2)
+        
+        self.assertRaises(ValueError, lf.setParamRule, 
+            'length', lower=2, upper=0)
+         
         
 if __name__ == '__main__':
     unittest.main()
