@@ -10,10 +10,10 @@ def a_c(x, y):
 from cogent.evolve.predicate import MotifChange, replacement
 
 __author__ = "Peter Maxwell and Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -33,7 +33,7 @@ class ScaleRuleTests(unittest.TestCase):
     def _getScaledLengths(self, model, params):
         LF = model.makeLikelihoodFunction(TREE)
         for param in params:
-            LF.setParamRule(param, value=params[param], is_const=True)
+            LF.setParamRule(param, value=params[param], is_constant=True)
         result = {}
         for predicate in model.scale_masks:
             result[predicate] = LF.getScaledLengths(predicate)['a']
@@ -53,9 +53,9 @@ class ScaleRuleTests(unittest.TestCase):
             'ts':trans, 'tv': ~trans})
                     
         LF = model.makeLikelihoodFunction(TREE, bins=2)
-        LF.setParamRule('length', value=4.0, is_const=True)
-        LF.setParamRule('k', value=6.0, bin='bin0', is_const=True)
-        LF.setParamRule('k', value=1.0, bin='bin1', is_const=True)
+        LF.setParamRule('length', value=4.0, is_constant=True)
+        LF.setParamRule('k', value=6.0, bin='bin0', is_constant=True)
+        LF.setParamRule('k', value=1.0, bin='bin1', is_constant=True)
 
         for (bin, expected) in [('bin0', 3.0), ('bin1', 4.0/3), (None, 13.0/6)]:
             self.assertEqual(LF.getScaledLengths('ts', bin=bin)['a'], expected)
@@ -137,4 +137,4 @@ if __name__ == '__main__':
     unittest.main()
 
 
-    
\ No newline at end of file
+    
