@@ -8,10 +8,10 @@ from cogent.core import alignment, tree
 from cogent.evolve import substitution_model
 
 __author__ = "Peter Maxwell and Gavin Huttley"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -56,11 +56,11 @@ print new_lf
 sm = substitution_model.Nucleotide(predicates={'kappa':'transition'})
 lf = sm.makeLikelihoodFunction(t)
 lf.setConstantLengths()
-lf.setParamRule('kappa',is_const = True, value = 4.0, edge_name='a')
-lf.setParamRule('kappa',is_const = True, value = 0.5, edge_name='b')
-lf.setParamRule('kappa',is_const = True, value = 0.2, edge_name='c')
-lf.setParamRule('kappa',is_const = True, value = 3.0, edge_name='d')
-lf.setParamRule('kappa',is_const = True, value = 2.0, edge_name='edge.0')
+lf.setParamRule('kappa',is_constant = True, value = 4.0, edge_name='a')
+lf.setParamRule('kappa',is_constant = True, value = 0.5, edge_name='b')
+lf.setParamRule('kappa',is_constant = True, value = 0.2, edge_name='c')
+lf.setParamRule('kappa',is_constant = True, value = 3.0, edge_name='d')
+lf.setParamRule('kappa',is_constant = True, value = 2.0, edge_name='edge.0')
 lf.setName('True Kappa model')
 print lf
 simulated = lf.simulateAlignment(sequence_length=length_of_align)
