@@ -1,5 +1,6 @@
 #!/usr/bin/env python
-__all__ = ['test_geometry',
+__all__ = ['test_fit_function',
+           'test_geometry',
            'test_matrix',
            'test_matrix_logarithm',
            'test_optimisers',
@@ -8,11 +9,11 @@ __all__ = ['test_geometry',
            'test_spatial']
 
 __author__ = ""
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Rob Knight", "Peter Maxwell", "Catherine Lozupone",
-               "Gavin Huttley", "Sandra Smit", "Marcin Cieslik"]
+               "Gavin Huttley", "Sandra Smit", "Marcin Cieslik", "Antonio Gonzalez Pena"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
