@@ -8,11 +8,12 @@ from numpy import array, sqrt, shape, ones, diag
             
             
 __author__ = "Justin Kuczynski"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __contributors__ = ["Justin Kuczynski",
-                    "Zongzhi Liu"]
+                    "Zongzhi Liu",
+                    "Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 __status__ = "Prototype"
@@ -41,6 +42,11 @@ class functionTests(TestCase):
                         [ 0.0,  0.0 ,  0.4],
                         [ 1.0,  0.0,  0.0 ],
                         [ 0.0,  0.0,  0.0 ]],'d')
+        self.input_binary_dist_otu_gain1 = array([[2,1,0,0],
+          [1,0,0,1],
+          [0,0,3,0],
+          [0,0,0,1]])
+                        
     
     def get_sym_mtx_from_uptri(self, mtx):
         """helper fn, only for square matrices"""
@@ -116,6 +122,21 @@ class functionTests(TestCase):
                             [ 19.9,  24.90,  0.0 ]],'d')
         self.assertFloatEqual(dist_manhattan(self.dense1), dense1expected)
     
+    def test_dist_abund_jaccard(self):
+        """dist_abund_jaccard should compute distances for dense1 and mtx1"""
+        mtx1_expected = array([[0, 0.25], [0.25, 0]], 'd')
+        self.assertEqual(dist_abund_jaccard(self.mtx1), mtx1_expected)
+
+        dense1_expected = zeros((3,3), 'd')
+        self.assertEqual(dist_abund_jaccard(self.dense1), dense1_expected)
+
+        sparse1_expected = array([
+            [0.0, 0.0, 1.0, 1.0],
+            [0.0, 0.0, 1.0, 1.0],
+            [1.0, 1.0, 0.0, 1.0],
+            [1.0, 1.0, 1.0, 0.0]], 'd')
+        self.assertEqual(dist_abund_jaccard(self.sparse1), sparse1_expected)
+ 
     def test_dist_morisita_horn(self):
         """tests dist_morisita_horn
         
@@ -216,12 +237,17 @@ class functionTests(TestCase):
         ex1expected = array([[0, ex1res],
                             [ex1res, 0]],'d')
         self.assertFloatEqual(dist_spearman_approx(ex1), ex1expected)
-        
-
-    
     
     # now binary fns
-                   
+    def test_binary_dist_otu_gain(self):
+        """ binary OTU gain functions as expected """
+        actual = binary_dist_otu_gain(self.input_binary_dist_otu_gain1)
+        expected = array([[0, 1, 2, 2],
+                          [1, 0, 2, 1],
+                          [1, 1, 0, 1],
+                          [1, 0, 1, 0]])
+        self.assertEqual(actual,expected)
+
     def test_binary_dist_chisq(self):
         """tests binary_dist_chisq
         
