@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 """Unit tests for fast unifrac."""
+from __future__ import division
 
 from numpy import array, logical_not, argsort
 from cogent.util.unit_test import TestCase, main
@@ -18,10 +19,11 @@ from cogent.maths.unifrac.fast_unifrac import (reshape_by_name,
 from numpy.random import permutation 
 
 __author__ = "Rob Knight and Micah Hamady"
-__copyright = "Copyright 2007, the authors."
-__credits__ = ["Rob Knight", "Micah Hamady", "Daniel McDonald"]
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
+__credits__ = ["Rob Knight", "Micah Hamady", "Daniel McDonald", 
+"Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight, Micah Hamady"
 __email__ = "rob@spot.colorado.edu, hamady@colorado.edu"
 __status__ = "Prototype"
@@ -213,20 +215,134 @@ f B 1
             result.append(rawp)
         self.assertSimilarMeans(result, 0.047)
 
-    def test_PD_whole_tree(self):
-        """PD_whole_tree should correctly compute PD for test tree."""
-        self.t1 = DndParser('((a:1,b:2):4,(c:3,(d:1,e:1):2):3)', \
-            UniFracTreeNode)
-        self.env_str = """
+    def test_unifrac_explicit(self):
+        """unifrac should correctly compute correct values.
+        
+        environment M contains only tips not in tree, tip j is in no envs
+        values were calculated by hand
+        """
+        t1 = DndParser('((a:1,b:2):4,((c:3, j:17),(d:1,e:1):2):3)', \
+            UniFracTreeNode) # note c,j is len 0 node
+        #           /-------- /-a
+        # ---------|          \-b
+        #          |          /-------- /-c
+        #           \--------|          \-j
+        #                     \-------- /-d
+        #                               \-e
+
+        env_str = """
         a   A   1
         a   C   2
         b   A   1
         b   B   1
         c   B   1
         d   B   3
-        e   C   1"""
-        env_counts = count_envs(self.env_str.splitlines())
-        self.assertEqual(PD_whole_tree(self.t1,self.env_counts), \
+        e   C   1
+        m   M   88"""
+        env_counts = count_envs(env_str.splitlines())
+        self.assertFloatEqual(fast_unifrac(t1,env_counts)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+        # changing tree topology relative to c,j tips shouldn't change 
+        # anything
+        t2 = DndParser('((a:1,b:2):4,((c:2, j:16):1,(d:1,e:1):2):3)', \
+            UniFracTreeNode)
+        self.assertFloatEqual(fast_unifrac(t2,env_counts)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+
+    def test_unifrac_make_subtree(self):
+        """unifrac result should not depend on make_subtree
+        
+        environment M contains only tips not in tree, tip j, k is in no envs
+        one clade is missing entirely
+        values were calculated by hand
+        we also test that we still have a valid tree at the end
+        """
+        t1 = DndParser('((a:1,b:2):4,((c:3, (j:1,k:2)mt:17),(d:1,e:1):2):3)',\
+            UniFracTreeNode) # note c,j is len 0 node
+        #           /-------- /-a
+        # ---------|          \-b
+        #          |          /-------- /-c
+        #           \--------|          \mt------ /-j
+        #                    |                    \-k
+        #                     \-------- /-d
+        #                               \-e
+        # 
+
+        env_str = """
+        a   A   1
+        a   C   2
+        b   A   1
+        b   B   1
+        c   B   1
+        d   B   3
+        e   C   1
+        m   M   88"""
+        env_counts = count_envs(env_str.splitlines())
+        self.assertFloatEqual(fast_unifrac(t1,env_counts,make_subtree=False)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+        self.assertFloatEqual(fast_unifrac(t1,env_counts,make_subtree=True)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+        # changing tree topology relative to c,j tips shouldn't change anything
+        t2 = DndParser('((a:1,b:2):4,((c:2, (j:1,k:2)mt:17):1,(d:1,e:1):2):3)', \
+            UniFracTreeNode)
+        self.assertFloatEqual(fast_unifrac(t2,env_counts,make_subtree=False)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+        self.assertFloatEqual(fast_unifrac(t2,env_counts,make_subtree=True)['distance_matrix'], \
+            (array(
+            [[0,10/16, 8/13],
+            [10/16,0,8/17],
+            [8/13,8/17,0]]),['A','B','C']))
+
+        # ensure we haven't meaningfully changed the tree 
+        # by passing it to unifrac
+        t3 = DndParser('((a:1,b:2):4,((c:3, (j:1,k:2)mt:17),(d:1,e:1):2):3)',\
+            UniFracTreeNode) # note c,j is len 0 node
+        t1_tips = [tip.Name for tip in t1.tips()]
+        t1_tips.sort()
+        t3_tips = [tip.Name for tip in t3.tips()]
+        t3_tips.sort()
+        
+        self.assertEqual(t1_tips, t3_tips)
+        tipj3 = t3.getNodeMatchingName('j')
+        tipb3 = t3.getNodeMatchingName('b')
+        tipj1 = t1.getNodeMatchingName('j')
+        tipb1 = t1.getNodeMatchingName('b')
+        self.assertFloatEqual(tipj1.distance(tipb1), tipj3.distance(tipb3))
+
+
+    def test_PD_whole_tree(self):
+        """PD_whole_tree should correctly compute PD for test tree.
+        
+        environment M contains only tips not in tree, tip j is in no envs
+        """
+        t1 = DndParser('((a:1,b:2):4,((c:3, j:17),(d:1,e:1):2):3)', \
+            UniFracTreeNode)
+        env_str = """
+        a   A   1
+        a   C   2
+        b   A   1
+        b   B   1
+        c   B   1
+        d   B   3
+        e   C   1
+        m   M   88"""
+        env_counts = count_envs(env_str.splitlines())
+        self.assertEqual(PD_whole_tree(t1,env_counts), \
             (['A','B','C'], array([7.,15.,11.])))
 
     def test_PD_generic_whole_tree(self):
