@@ -1,22 +1,25 @@
 #! /usr/bin/env python
 import unittest, os
 import warnings
-
+from numpy import log, exp
 warnings.filterwarnings('ignore', 'Not using MPI as mpi4py not found')
 
-from cogent.phylo.distance import *
+from cogent.phylo.distance import EstimateDistances
 from cogent.phylo.nj import nj, gnj
 from cogent.phylo.least_squares import wls
 from cogent import LoadSeqs, LoadTree
+from cogent.phylo.tree_collection import LogLikelihoodScoredTreeCollection,\
+    WeightedTreeCollection, LoadTrees
 from cogent.evolve.models import JC69, HKY85, F81
 from cogent.phylo.consensus import majorityRule, weightedMajorityRule
+from cogent.util.misc import remove_files
 
 __author__ = "Peter Maxwell"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Peter Maxwell", "Gavin Huttley", "Matthew Wakefield",\
         "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Gavin Huttley"
 __email__ = "gavin.huttley@anu.edu.au"
 __status__ = "Production"
@@ -27,24 +30,69 @@ def Tree(t):
 class ConsensusTests(unittest.TestCase):
     def setUp(self):
         self.trees = [
-                (1, Tree("((a,b),(c,d));")),
-                (1, Tree("((a,b),(c,d));")),
-                (1, Tree("((a,c),(b,d));")),
-                (1, Tree("((a,b),c,d);")),]
+                Tree("((a,b),(c,d));"),
+                Tree("((a,b),(c,d));"),
+                Tree("((a,c),(b,d));"),
+                Tree("((a,b),c,d);")]
+        
+        data = zip(map(log, [0.4,0.4,0.05,0.15]), # emphasizing the a,b clade
+        self.trees)
+        data.sort()
+        data.reverse()
+        self.scored_trees = data
     
     def test_majorityRule(self):
         """Tests for majority rule consensus trees"""
-        trees = [t for (w,t) in self.trees]
+        trees = self.trees
         outtrees = majorityRule(trees, strict=False)
         self.assertEqual(len(outtrees), 1)
         self.assert_(outtrees[0].sameTopology(Tree("((c,d),(a,b));")))
         outtrees = majorityRule(trees, strict=True)
         self.assertEqual(len(outtrees), 1)
         self.assert_(outtrees[0].sameTopology(Tree("(c,d,(a,b));")))
+    
+    def test_consensus_from_scored_trees_collection(self):
+        """tree collection should get same consensus as direct approach"""
+        sct = LogLikelihoodScoredTreeCollection([(1, t) for t in self.trees])
+        ct = sct.getConsensusTree()
+        self.assertTrue(ct.sameTopology(Tree("((c,d),(a,b));")))
+    
+    def test_weighted_consensus_from_scored_trees_collection(self):
+        """weighted consensus from a tree collection should be different"""
+        sct = LogLikelihoodScoredTreeCollection(self.scored_trees)
+        ct = sct.getConsensusTree()
+        self.assertTrue(ct.sameTopology(Tree("((a,b),(c,d));")))
+    
+    def test_weighted_trees_satisyfing_cutoff(self):
+        """build consensus tree from those satisfying cutoff"""
+        sct = LogLikelihoodScoredTreeCollection(self.scored_trees)
+        cts = sct.getWeightedTrees(cutoff=0.8)
+        expected_trees = [Tree(t) for t in "((a,b),(c,d));", "((a,b),(c,d));",
+                                "((a,b),c,d);"]
+        for i in range(len(cts)):
+            cts[i][1].sameTopology(expected_trees[i])
+        
+        ct = cts.getConsensusTree()
+        self.assertTrue(ct.sameTopology(Tree("((a,b),(c,d));")))
+    
+    def test_tree_collection_read_write_file(self):
+        """should correctly read / write a collection from a file"""
+        def eval_klass(coll):
+            coll.writeToFile('sample.trees')
+            read = LoadTrees('sample.trees')
+            self.assertTrue(type(read) == type(coll))
+        
+        eval_klass(LogLikelihoodScoredTreeCollection(self.scored_trees))
+        
+        # convert lnL into p
+        eval_klass(WeightedTreeCollection([(exp(s), t) 
+                                    for s,t in self.scored_trees]))
+        remove_files(['sample.trees'], error_on_missing=False)
+    
 
 class TreeReconstructionTests(unittest.TestCase):
     def setUp(self):
-        self.tree = LoadTree(treestring='((a:3,b:4):2,(c:6,d:7):30,e:5)')
+        self.tree = LoadTree(treestring='((a:3,b:4):2,(c:6,d:7):30,(e:5,f:5):5)')
         self.dists = self.tree.getDistances()
         
     def assertTreeDistancesEqual(self, t1, t2):
@@ -86,7 +134,7 @@ class TreeReconstructionTests(unittest.TestCase):
 
     def test_wls(self):
         """testing wls"""
-        reconstructed = wls(self.dists)
+        reconstructed = wls(self.dists, a=4)
         self.assertTreeDistancesEqual(self.tree, reconstructed)
 
     def test_truncated_wls(self):
@@ -99,18 +147,17 @@ class TreeReconstructionTests(unittest.TestCase):
         """testing (well, exercising at least), wls with constrained start"""
         init = LoadTree(treestring='((a,c),b,d)')
         reconstructed = wls(self.dists, start=init)
-        self.assertEqual(len(reconstructed.getTipNames()), 5)
+        self.assertEqual(len(reconstructed.getTipNames()), 6)
         init2 = LoadTree(treestring='((a,d),b,c)')
         reconstructed = wls(self.dists, start=[init, init2])
-        self.assertEqual(len(reconstructed.getTipNames()), 5)
-        init3 = LoadTree(treestring='((a,d),b,e)')
+        self.assertEqual(len(reconstructed.getTipNames()), 6)
+        init3 = LoadTree(treestring='((a,d),b,z)')
         self.assertRaises(Exception, wls, self.dists, start=[init, init3])
         # if start tree has all seq names, should raise an error
         self.assertRaises(Exception, wls, self.dists,
-                start=[LoadTree(treestring='((a,c),b,(d,e))')])
+                start=[LoadTree(treestring='((a,c),b,(d,(e,f)))')])
         
     
-
 class DistancesTests(unittest.TestCase):
     def setUp(self):
         self.al = LoadSeqs(data = {'a':'GTACGTACGATC',
@@ -215,7 +262,7 @@ class DistancesTests(unittest.TestCase):
     def test_EstimateDistances_modify_lf(self):
         """tests modifying the lf"""
         def constrain_fit(lf):
-            lf.setParamRule('kappa', is_const=True)
+            lf.setParamRule('kappa', is_constant=True)
             lf.optimise(local=True)
             return lf
         
