@@ -30,11 +30,11 @@ from numpy import array
 from time import clock, sleep
 
 __author__ = "Rob Knight"
-__copyright__ = "Copyright 2007-2009, The Cogent Project"
+__copyright__ = "Copyright 2007-2011, The Cogent Project"
 __credits__ = ["Rob Knight", "Amanda Birmingham", "Sandra Smit",
                     "Zongzhi Liu", "Peter Maxwell", "Daniel McDonald"]
 __license__ = "GPL"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 __maintainer__ = "Rob Knight"
 __email__ = "rob@spot.colorado.edu"
 __status__ = "Production"
@@ -128,7 +128,7 @@ class UtilsTests(TestCase):
 
     def test_safe_md5(self):
         """Make sure we have the expected md5"""
-        exp = '29fa8614a884efe6a5604b7ef1af7378'
+        exp = '8351caf492a97864cf8af555438ab851'
         obs = safe_md5(open('test_util/__init__.py'))
         self.assertEqual(obs.hexdigest(),exp)
 
@@ -1428,9 +1428,7 @@ class reverse_complementTests(TestCase):
         """reverse_complement should just reverse any chars but ACGT/U"""
         
         user_input = "BDeF"
-        correct_output = "FeDB"
-        real_output = reverse_complement(user_input)
-        self.assertEquals(real_output, correct_output)   
+        self.assertRaises(ValueError,reverse_complement,user_input)
     #end test_reverse_complement_nonNucleicSeq
     
     def test_reverse_complement_emptySeq(self):
